<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://theme-kiwi.com
 * @since      1.0.0
 *
 * @package    Marketplace_Edd_Vcaddons
 * @subpackage Marketplace_Edd_Vcaddons/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Marketplace_Edd_Vcaddons
 * @subpackage Marketplace_Edd_Vcaddons/admin
 * @author     Kiarashi <no@spam.com>
 */
class Marketplace_Edd_Vcaddons_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Marketplace_Edd_Vcaddons_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Marketplace_Edd_Vcaddons_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/marketplace-edd-vcaddons-admin.css', array(), $this->version, 'all' );
		
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Marketplace_Edd_Vcaddons_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Marketplace_Edd_Vcaddons_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/marketplace-edd-vcaddons-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	
	/**
	 * Register the demo stylesheet and add it inside the EDD Styling Tab.
	 *
	 * @since    1.0.0
	 */
	public function kiwi_demo_style_edd_settings($settings) {	
		$mp_vc_settings = array(
			'vcaddons_style_header' => array(
				'id'    => 'mp_vc_demo_style',
				'name'  => '<strong>' . esc_html__('VC Addon Styles', 'kiwi' ) . '</strong>',
				'desc'  => esc_html__('Configure VC Addon styles', 'kiwi' ),
				'type'  => 'header'
			),
			array(
				'id'    => 'mp_vc_demo_style_enbale',
				'name'  => esc_html__('Enable Demo Stylesheet', 'kiwi' ),
				'desc'  => esc_html__('Check to enable the stylesheet from the demo.', 'kiwi' ),
				'type'  => 'checkbox'
			)
		);

		return array_merge( $settings, $mp_vc_settings );
	}
	
	
	
	
	/**
	 * Import sample pages
	 *
	 * @since    1.1.0
	 */
	public function kiwi_demo_pages_edd_settings($settings) {	
		$mp_pages_settings = array(
			'vcaddons_demo_pages' => array(
				'id'    => 'mp_vc_demo_pages',
				'name'  => '<strong>' . esc_html__('VC Addon Demo Pages', 'kiwi' ) . '</strong>',
				'desc'  => esc_html__('Import demo pages that are included with the VC plugin.', 'kiwi' ),
				'type'  => 'header'
			),
			array(
				'id'    => 'mp_vc_demo_pages_import',
				'name'  => esc_html__('Create demo pages', 'kiwi' ),
				'desc'  => esc_html__('Check to import several demo pages', 'kiwi' ),
				'type'  => 'checkbox'
			)
		);

		return array_merge( $settings, $mp_pages_settings );
	}
	
	
	
	
	
	
	
	/**
	 * Register the Submenu :: Visual Composer
	 *
	 * @since    1.0.0
	 */
	public function kiwi_register_custom_submenu_page() {

	 $theme = wp_get_theme();
	
		if ('Theme Kiwi :: Marketplace' == $theme->name || 'Theme Kiwi :: Marketplace' == $theme->parent_theme) {	
			
		} else { 	
			add_submenu_page(
				'edit.php?post_type=download',
				esc_html__( 'EDD Visual Composer Addons', 'kiwi' ),
				esc_html__( 'Kiwi :: VC Addons', 'kiwi' ),
				'manage_options',
				'kiwi_vc_about_page',
				array( $this, 'kiwi_vc_about_page' )			
			);			
		}	
		
 	}	
	
	
	public function kiwi_vc_about_page(){
		include_once( 'partials/marketplace-edd-vcaddons-admin-display.php' );
	}
	
	
	
	
	
	
	
	
	
	
	/**
	 * Create Demo Pages
	 *
	 * @since 1.1.0
	 *	
	 */
	public function kiwi_create_plugin_pages() {
		
		if( class_exists( 'Easy_Digital_Downloads' ) && edd_get_option( 'mp_vc_demo_pages_import', false ) == true ) {		
			
			// VC Addons - All
			if( ! get_page_by_path('vc-plugin-preview-all') ){
				$page = array(
					'post_author' 	=> get_current_user_id(),
					'post_status' 	=> 'publish',
					'post_title'  	=> __( 'VC Plugin Preview - All', 'kiwi' ),
					'post_name'   	=> 'vc-plugin-preview-all',
					'post_type'   	=> 'page',
					'post_content'  => '[vc_row bg_type="bg_color" bg_override="full" css=".vc_custom_1451922133486{margin-bottom: 0px !important;padding-top: 60px !important;padding-bottom: 60px !important;}" bg_color_value="#f2f2f3"][vc_column css=".vc_custom_1454923613705{margin-top: 0px !important;padding-top: 0px !important;}"][vc_custom_heading text="100% Easy Digital Downloads compatible" font_container="tag:div|font_size:18px|text_align:center|color:%238b8b8b" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal" el_class="letter-spacing-two"][vc_column_text css=".vc_custom_1463867828903{margin-bottom: 0px !important;padding-bottom: 0px !important;}"]<div style="color: #333333; font-size: 30px; font-family: Roboto; text-align: center;">7 Exclusive <span style="color: #dd3c66; font-weight: bold;">Visual Composer</span> Addons</div>[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row" bg_type="image" parallax_style="vcpb-default" bg_image_new="id^8545|url^http://theme-kiwi.com/mp-demo/wp-content/uploads/sites/5/2016/02/img-wireframe05.jpg|caption^null|alt^null|title^img-wireframe05|description^null" bg_image_repeat="no-repeat" bg_image_size="contain" bg_img_attach="fixed" bg_image_posiiton="top center" bg_override="full" seperator_enable="seperator_enable_value" seperator_type="triangle_svg_seperator" seperator_svg_height="40" seperator_shape_background="#f2f2f3" css=".vc_custom_1454923000739{margin-bottom: 0px !important;padding-top: 80px !important;padding-bottom: 80px !important;background-color: #252525 !important;}"][vc_column][eddgridkiwi filter_max_items="5" mp_filter_options="filter-categories" total_items="18" mp_grid_design_layout="multi-layout" mp_grid_design_columns="design_columns_three" thumbnail_size="80" thumbnail_size_height="80" mp_griddesign_excerpt_length="13" mp_griddesign_excerpt_ending="..." truncate_title="yes" grid_truncate_lenght="one-line" filter_load_multilayout="imageview" mp_offset="0" grid_extra_styling_box="yes" grid_spacing_box="5px" grid_extra_styling_filter="yes" grid_extra_styling_filter_textcolor="#ffffff" grid_extra_styling_filter_bgcolor="rgba(255,255,255,0.1)" grid_extra_styling_filter_spacing_box="5px" grid_extra_styling_filter_bgcolor_active="#ffffff" grid_extra_styling_filter_bgcolor_hover="#ffffff" grid_extra_styling_filter_text_active="#323245" grid_extra_styling_filter_text_hover="#323245" filter_load_categories="all"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1451923639330{margin-bottom: 0px !important;padding-top: 30px !important;padding-bottom: 60px !important;background-color: #ffffff !important;}"][vc_column width="2/3"][vc_row_inner][vc_column_inner][eddpostmp heading_text="Free items" mp_layout_style=" layout_style_one" total_items="3" thumbnail_size="80" thumbnail_size_height="80" mp_post_excerpt_length="50" mp_post_excerpt_ending="..." mp_post_excerpt_link="View full description »" truncate_title="yes" grid_truncate_lenght="one-line" mp_offset="0"][vc_empty_space height="20px"][/vc_column_inner][/vc_row_inner][vc_row_inner css=".vc_custom_1454934740804{padding-top: 30px !important;}"][vc_column_inner width="1/2"][eddpostmp heading_text="Wordpress" mp_layout_style=" layout_style_two" total_items="3" thumbnail_size="80" thumbnail_size_height="80" mp_post_excerpt_length="20" mp_post_excerpt_ending="..." mp_post_excerpt_link="View full description »" truncate_title="yes" grid_truncate_lenght="one-line" mp_orderby="rand" mp_offset="0" mp_exclude="180,182"][/vc_column_inner][vc_column_inner width="1/2"][eddpostmp heading_text="Graphics" mp_layout_style=" layout_style_two" total_items="3" thumbnail_size="80" thumbnail_size_height="80" mp_post_excerpt_length="20" mp_post_excerpt_ending="..." mp_post_excerpt_link="View full description »" truncate_title="yes" grid_truncate_lenght="one-line" mp_orderby="rand" mp_sorting="ASC" mp_offset="0"][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="1/3"][eddpostmp heading_text="Random items" mp_layout_style=" layout_style_three" total_items="5" thumbnail_size="80" thumbnail_size_height="80" mp_post_excerpt_length="20" mp_post_excerpt_ending="..." mp_post_excerpt_link="View full description »" truncate_title="yes" grid_truncate_lenght="one-line" mp_orderby="rand" mp_offset="0"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces" bg_type="bg_color" bg_override="full" css=".vc_custom_1458057505768{margin-top: 0px !important;margin-right: 0px !important;margin-bottom: 0px !important;margin-left: 0px !important;border-top-width: 0px !important;border-right-width: 0px !important;border-bottom-width: 0px !important;border-left-width: 0px !important;padding-top: 0px !important;padding-right: 0px !important;padding-bottom: 0px !important;padding-left: 0px !important;background-color: #18a9c4 !important;}" bg_color_value="#18a9c4" el_class="disable"][vc_column width="1/4" el_class="col-xs-12" css=".vc_custom_1451666227279{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 0px !important;}"][vc_empty_space height="85px"][vc_custom_heading text="Work in Progress" font_container="tag:div|font_size:16px|text_align:center|color:%23ffffff" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal"][vc_custom_heading text="UPCOMING" font_container="tag:div|font_size:40px|text_align:center|color:%23ffffff|line_height:40px" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal"][/vc_column][vc_column width="3/4" el_class="col-xs-12" css=".vc_custom_1451673373793{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 0px !important;background-color: #ffffff !important;}"][eddslider total_items="10" setting_fade="false" items_per_view="2" items_per_scroll="2" slide_autoplay="true" autoplay_speed="2000" infinite_loop="true" slide_speed="2000" adaptive_height="false" item_rtl="false" arrows="false" dots="false" slide_nav_layout="style-one" setting_design="grid_style_one" hide_caption="yes" slider_offset="0" slide_breakpoint_small="1" slide_scroll_small="1" slide_breakpoint_small_arrows="false" slide_breakpoint_small_dots="false" slide_breakpoint_middle="2" slide_scroll_middle="2" slide_breakpoint_middle_arrows="false" slide_breakpoint_middle_dots="false"][/vc_column][/vc_row][vc_row full_width="stretch_row" bg_type="bg_color" bg_override="full" css=".vc_custom_1458057397945{margin-bottom: 0px !important;padding-top: 40px !important;padding-bottom: 0px !important;background-color: #ffffff !important;}" bg_color_value="#ffffff"][vc_column][eddslider heading_text="Audio *NEW*" total_items="6" setting_fade="false" items_per_view="3" items_per_scroll="1" slide_autoplay="true" autoplay_speed="2000" infinite_loop="true" slide_speed="2000" adaptive_height="false" item_rtl="false" slides_spacing="5" arrows="true" dots="false" slide_nav_layout="style-two" setting_design="grid_style_three" grid_style_two_truncate_title="yes" grid_truncate_lenght="one-line" slider_offset="0" slide_breakpoint_small="1" slide_scroll_small="1" slide_breakpoint_small_arrows="false" slide_breakpoint_small_dots="false" slide_breakpoint_middle="1" slide_scroll_middle="1" slide_breakpoint_middle_arrows="false" slide_breakpoint_middle_dots="false" grid_extra_styling_box="yes" grid_background_box="#ffffff"][vc_empty_space height="40px"][vc_row_inner][vc_column_inner width="2/3"][eddslider heading_text="Video *NEW*" total_items="2" setting_fade="false" items_per_view="2" items_per_scroll="2" slide_autoplay="false" autoplay_speed="2000" infinite_loop="true" slide_speed="2000" adaptive_height="false" item_rtl="false" slides_spacing="5" arrows="false" dots="false" slide_nav_layout="style-one" setting_design="grid_style_two" grid_style_two_excerpt_length="13" grid_style_two_excerpt_ending="..." grid_style_two_excerpt_link="more »" grid_style_two_truncate_title="yes" grid_truncate_lenght="two-lines" slider_offset="0" slide_breakpoint_small="1" slide_scroll_small="1" slide_breakpoint_small_arrows="false" slide_breakpoint_small_dots="false" slide_breakpoint_middle="1" slide_scroll_middle="1" slide_breakpoint_middle_arrows="false" slide_breakpoint_middle_dots="false" grid_extra_styling_box="yes" grid_background_box="#ffffff"][/vc_column_inner][vc_column_inner width="1/3"][eddslider heading_text="HD stock photos" total_items="6" setting_fade="true" items_per_view="1" items_per_scroll="1" slide_autoplay="true" autoplay_speed="2000" infinite_loop="true" slide_speed="2000" adaptive_height="false" item_rtl="false" arrows="true" dots="true" slide_nav_layout="style-one" setting_design="grid_style_one" slider_offset="0" slide_breakpoint_small="1" slide_scroll_small="1" slide_breakpoint_small_arrows="false" slide_breakpoint_small_dots="false" slide_breakpoint_middle="1" slide_scroll_middle="1" slide_breakpoint_middle_arrows="false" slide_breakpoint_middle_dots="false" grid_extra_styling_box="yes" grid_background_box="#ffffff"][/vc_column_inner][/vc_row_inner][vc_empty_space height="40px"][/vc_column][/vc_row][vc_row full_width="stretch_row" bg_type="image" parallax_style="vcpb-default" bg_image_new="id^8545|url^http://theme-kiwi.com/mp-demo/wp-content/uploads/sites/5/2016/02/img-wireframe05.jpg|caption^null|alt^null|title^img-wireframe05|description^null" bg_image_repeat="no-repeat" bg_image_size="contain" bg_img_attach="fixed" bg_image_posiiton="top center" bg_override="full" seperator_enable="seperator_enable_value" seperator_type="triangle_svg_seperator" seperator_svg_height="40" seperator_shape_background="#f2f2f3" css=".vc_custom_1454923000739{margin-bottom: 0px !important;padding-top: 80px !important;padding-bottom: 80px !important;background-color: #252525 !important;}"][vc_column][vc_custom_heading text="New slider option :: Center Mode" font_container="tag:h2|font_size:20px|text_align:center|color:%23ffffff|line_height:26px" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:300%20light%20regular%3A300%3Anormal" css=".vc_custom_1463868444054{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row_content" bg_type="image" parallax_style="vcpb-default" bg_image_new="id^8545|url^http://theme-kiwi.com/mp-demo/wp-content/uploads/sites/5/2016/02/img-wireframe05.jpg|caption^null|alt^null|title^img-wireframe05|description^null" bg_image_repeat="no-repeat" bg_image_size="contain" bg_img_attach="fixed" bg_image_posiiton="top center" bg_override="full" seperator_enable="seperator_enable_value" seperator_type="triangle_svg_seperator" seperator_svg_height="40" seperator_shape_background="#f2f2f3" css=".vc_custom_1463487486361{margin-top: 0px !important;margin-right: 0px !important;margin-bottom: 0px !important;margin-left: 0px !important;padding-top: 0px !important;padding-right: 0px !important;padding-bottom: 80px !important;padding-left: 0px !important;background-color: #252525 !important;}"][vc_column css=".vc_custom_1463487474401{margin-top: 0px !important;margin-right: 0px !important;margin-bottom: 0px !important;margin-left: 0px !important;border-top-width: 0px !important;border-right-width: 0px !important;border-bottom-width: 0px !important;border-left-width: 0px !important;padding-top: 0px !important;padding-right: 0px !important;padding-bottom: 0px !important;padding-left: 0px !important;}"][eddslider total_items="6" setting_fade="false" items_per_view="2" items_per_scroll="1" slide_autoplay="true" autoplay_speed="2000" infinite_loop="true" slide_speed="2000" adaptive_height="false" item_rtl="false" slides_spacing="10" arrows="false" dots="true" slide_nav_layout="style-one" setting_design="grid_style_one" grid_style_two_truncate_title="yes" grid_truncate_lenght="one-line" mp_slider_centermode="yes" mp_slider_centermode_opacity="yes" mp_slider_centermode_padding="80" hide_caption="yes" slider_offset="0" slider_category="187" slide_breakpoint_small="1" slide_scroll_small="1" slide_breakpoint_small_arrows="false" slide_breakpoint_small_dots="true" slide_breakpoint_middle="2" slide_scroll_middle="1" slide_breakpoint_middle_arrows="false" slide_breakpoint_middle_dots="true" grid_extra_styling_box="yes"][/vc_column][/vc_row][vc_row full_width="stretch_row" bg_type="bg_color" bg_override="full" css=".vc_custom_1458057652648{margin-bottom: 0px !important;padding-top: 40px !important;padding-bottom: 60px !important;background-color: #ffffff !important;}" bg_color_value="#ffffff"][vc_column width="1/3"][kiwiloader subcat_options="options-categories" subcat_category="187" subcat_heading_text="Suspendisse feugiat pulvinar gravida. Morbi at quam sit amet lorem euismod gravida." show_subcat="yes" show_catcount="yes" limit_author="5" subcat_button_text=" View all items inside this category."][/vc_column][vc_column width="2/3"][eddrecent mp_grid_pagination="yes" mp_grid_pagination_alignment="center" mp_category="187" total_items="9" mp_grid_design_layout="gridstyle-two" mp_grid_design_columns="design_columns_three" mp_grid_design_layout_hide_caption="yes" truncate_title="yes" grid_truncate_lenght="one-line" mp_offset="0"][/vc_column][/vc_row][vc_row full_width="stretch_row" bg_type="bg_color" bg_override="full" css=".vc_custom_1459262472080{margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 80px !important;background-color: #ffffff !important;}" bg_color_value="#fafafa"][vc_column][eddauthor author_id="3" link_portfolio="yes" link_authorinfo="yes" link_authorport="yes" portfolio_heading_text="Author\'s best selling items. (TOOLTIP ENABLED)" portfolio_heading_text_position="below" author_total_items="5" author_layout_style="thumbnails" author_thumbnail_size="80" author_thumbnail_size_height="80" mp_tooltip_thumbnails="yes" author_thumbnail_styling="yes" author_thumbnail_border="1px solid #e8e8e8" author_thumbnail_padding="5px" author_thumbnail_background="#ffffff" mp_author_offset="0"][/vc_column][/vc_row][vc_row full_width="stretch_row" bg_type="bg_color" bg_override="full" css=".vc_custom_1459262472080{margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 80px !important;background-color: #ffffff !important;}" bg_color_value="#fafafa"][vc_column][mpauthors mp_no_vendors="10" link_authorinfo="yes" link_authorport="yes" link_portfolio="yes" portfolio_heading_text="Author\'s random items." portfolio_heading_text_position="below" author_total_items="6" author_layout_style="thumbnails" author_thumbnail_size="80" author_thumbnail_size_height="80" mp_tooltip_thumbnails="yes" author_thumbnail_styling="yes" author_thumbnail_border="1px solid #e8e8e8" author_thumbnail_padding="5px" author_thumbnail_background="#ffffff" author_truncate_title="yes" mp_author_orderby="rand" mp_author_offset="0"][/vc_column][/vc_row]',
				);
				$kiwi_demo_main = wp_insert_post( $page );
			}
			
			
			// Full Width :: Grid VC Addon
			if( ! get_page_by_path('vc-plugin-preview-grid') ){
				$page = array(
					'post_author' 	=> get_current_user_id(),
					'post_status' 	=> 'publish',
					'post_title'  	=> __( 'VC Plugin Preview - Grid', 'kiwi' ),
					'post_name'   	=> 'vc-plugin-preview-grid',
					'post_type'   	=> 'page',
					'post_content'  => '[vc_row full_width="stretch_row" css=".vc_custom_1463866274506{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 80px !important;padding-bottom: 80px !important;background-color: #303030 !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column css=".vc_custom_1453461635860{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 0px !important;}"][vc_custom_heading text="Don\'t forget to read the documentation if you need help with this." font_container="tag:h2|font_size:20px|text_align:center|color:%23e8e8e8|line_height:30px" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal" css=".vc_custom_1454243914968{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 20px !important;}"][vc_custom_heading text="VC Grid Addon :: Full Width" font_container="tag:h2|font_size:50px|text_align:center|color:%23ffffff" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal" css=".vc_custom_1454245261366{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 20px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row_content" css=".vc_custom_1453891311616{margin-top: 0px !important;margin-right: 0px !important;margin-bottom: 0px !important;margin-left: 0px !important;border-top-width: 0px !important;border-right-width: 0px !important;border-bottom-width: 0px !important;border-left-width: 0px !important;padding-top: 0px !important;padding-right: 0px !important;padding-bottom: 0px !important;padding-left: 0px !important;}"][vc_column css=".vc_custom_1453825015818{margin: 0px !important;border-width: 0px !important;padding: 0px !important;}"][eddrecent mp_grid_pagination="yes" mp_grid_pagination_alignment="center" total_items="12" mp_grid_design_layout="gridstyle-two" mp_grid_design_columns="design_columns_three" mp_grid_design_layout_hide_caption="yes" truncate_title="yes" grid_truncate_lenght="one-line" mp_offset="0" grid_container_fullwidth_items="yes" kiwi_divider_meta=""][/vc_column][/vc_row]',
				);
				$kiwi_demo_grid = wp_insert_post( $page );
			}
			
			
			
			// Full Width :: Filter VC Addon
			if( ! get_page_by_path('vc-plugin-preview-filter-addon') ){
				$page = array(
					'post_author' 	=> get_current_user_id(),
					'post_status' 	=> 'publish',
					'post_title'  	=> __( 'VC Plugin Preview - Filter', 'kiwi' ),
					'post_name'   	=> 'vc-plugin-preview-filter-addon',
					'post_type'   	=> 'page',
					'post_content'  => '[vc_row full_width="stretch_row" css=".vc_custom_1454854243585{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 80px !important;padding-bottom: 80px !important;background-image: url(http://theme-kiwi.com/import/wp-content/uploads/sites/3/2016/02/img-wallpaper-12.jpg?id=8673) !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column css=".vc_custom_1453461635860{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 0px !important;}"][vc_custom_heading text="Don\'t forget to read the documentation if you need help with this." font_container="tag:h2|font_size:20px|text_align:center|color:%23e8e8e8|line_height:30px" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal" css=".vc_custom_1454243914968{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 20px !important;}"][vc_custom_heading text="VC Filter Addon :: Full Width" font_container="tag:h2|font_size:50px|text_align:center|color:%23ffffff" google_fonts="font_family:Roboto%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C500%2C500italic%2C700%2C700italic%2C900%2C900italic|font_style:400%20regular%3A400%3Anormal" css=".vc_custom_1454243978762{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 0px !important;padding-bottom: 20px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row_content" css=".vc_custom_1453891311616{margin-top: 0px !important;margin-right: 0px !important;margin-bottom: 0px !important;margin-left: 0px !important;border-top-width: 0px !important;border-right-width: 0px !important;border-bottom-width: 0px !important;border-left-width: 0px !important;padding-top: 0px !important;padding-right: 0px !important;padding-bottom: 0px !important;padding-left: 0px !important;}"][vc_column css=".vc_custom_1453825015818{margin: 0px !important;border-width: 0px !important;padding: 0px !important;}"][eddgridkiwi total_items="24" mp_filter_options="filter-categories" filter_max_items="4" mp_speech_bubble="yes" mp_grid_design_layout="gridstyle-two" mp_grid_design_layout_hide_caption="yes" mp_grid_design_columns="design_columns_three" mp_offset="0" grid_extra_styling_filter="yes" grid_container_class="yes" grid_container_fullwidth_items="yes" grid_filter_div_bg_color="#32c5d2" grid_extra_styling_filter_textcolor="#ffffff" grid_extra_styling_filter_spacing_box="15px 0px" grid_extra_styling_filter_text_active="#2e3740" grid_extra_styling_filter_text_hover="#2e3740" mp_speech_bubble_arrow_color="#32c5d2" mp_speech_bubble_arrow_size="15" filter_load_categories="all" filter_fontsize="16px" filter_fontfamily="Roboto" filter_include_categories="252,237,187,195" grid_exclude="16,181"][/vc_column][/vc_row]',
				);
				$kiwi_demo_filter = wp_insert_post( $page );
			}
			
		}	
				
	}
	
	
	

}


	/**
	 * Register new Visual Composer Param :: Heading
	 *
	 * @since    1.1.0
	 */

	 
	if ( class_exists('Vc_Manager')) {	 
	
	
		function kiwi_param_heading_settings( $settings, $value ) {
			$title = isset( $settings[ 'title' ] ) ? '<div class="wpb_element_label kiwi-vc-heading">' . $settings[ 'title' ] . '</div>' : '';
			$subtitle = isset( $settings[ 'subtitle' ] ) ? '<span class="vc_description vc_clearfix">' . $settings[ 'subtitle' ] . '</span>' : '';

			$input = '<input id="' . esc_attr( $settings[ 'param_name' ] ) . '" class="wpb_vc_param_value" name="' . esc_attr( $settings[ 'param_name' ] ) . '" value="" type="hidden">';
			
			return $input . $title . $subtitle;
		}
		vc_add_shortcode_param( 'kiwi_vc_param_heading', 'kiwi_param_heading_settings' );
		
		
		function kiwi_param_divider_settings( $settings, $value ) {
			
				$html = '<div class="kiwi-vc-divider"></div>';
				
				return $html;
		}
		vc_add_shortcode_param( 'kiwi_vc_param_divider', 'kiwi_param_divider_settings' );
		
		
	}
