<?php

// don't load directly
if (!defined('ABSPATH')) die('-1');


class VCExtendAddonClass {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'integrateWithVC' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'eddrecent', array( $this, 'renderMyeddrecent' ) );

        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
    }
 
    public function integrateWithVC() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
		
$categories_array = array( esc_html__( 'All Categories', 'kiwi' ) => '' );
$category_list = get_terms( 'download_category', array( 'hide_empty' => false ) );

	if ( is_array( $category_list ) && ! empty( $category_list ) ) {
		foreach ( $category_list as $category_details ) {	
			$begin = esc_html__(' (ID: ', 'kiwi');
			$end = esc_html__(')', 'kiwi');
			$categories_array[ $category_details->name . $begin . $category_details->term_id . $end ] = $category_details->term_id;	
		}
	} 
		 
        vc_map( array(
            "name" => esc_html__("Marketplace :: Grid", 'kiwi'),
            "description" => esc_html__("A grid display of items.", 'kiwi'),
            "base" => "eddrecent",
            "class" => "",
            "controls" => "full",		
            "icon" => "icon-kiwi-grid",
			"category" => esc_html__('Theme :: Kiwi', 'kiwi'),
            'admin_enqueue_css' => array(plugins_url('css/kiwi-vc-addon.css', __FILE__)), 
			"params" => array(
    
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Heading text', 'kiwi' ),
		'param_name' => 'heading_text',
		'value' => '', 
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Add title (e.g., Latest Additions)', 'kiwi' ),
		
	),
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Total items', 'kiwi' ),
		'param_name' => 'total_items',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('Set max limit for items in grid.', 'kiwi' ),
		//'edit_field_class' => 'vc_col-sm-4 vc_column',
	),
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable pagination?', 'kiwi' ),
		'param_name' => 'mp_grid_pagination',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Pagination Alignment', 'kiwi' ),
			'param_name' => 'mp_grid_pagination_alignment',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Left', 'kiwi' ) => 'left',
				esc_html__( 'Center', 'kiwi' ) => 'center',	
				esc_html__( 'Right', 'kiwi' ) => 'right',	
				),	
			'dependency' => Array('element' => 'mp_grid_pagination', 'value' => 'yes' ),		
	),
	
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Select Category', 'kiwi' ),
			'param_name' => 'mp_category',
			'value' => $categories_array,			
			'description' => esc_html__('Select category or leave as it is for all.', 'kiwi' ),
			//'std' => '1/1'
	), 
	
		
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add read more link?', 'kiwi' ),
		'param_name' => 'readmore_link',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Read more text link', 'kiwi' ),
		'param_name' => 'readmore_text',
		'value' => '', // default value
		'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('(e.g., View more items in this category).', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	
	array(
		'type' => 'vc_link',
		'heading' => esc_html__('Add url here', 'kiwi' ),
		'param_name' => 'mp_url_more',
		'value' => '',
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
	),
	
	
	// Design Settings
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Layout', 'kiwi' ),
			'param_name' => 'mp_grid_design_layout',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Thumbnails only', 'kiwi' ) => 'thumbnails-only',
				esc_html__( 'Grid style 1', 'kiwi' ) => 'gridstyle-one',
				esc_html__( 'Grid style 2', 'kiwi' ) => 'gridstyle-two',	
				esc_html__( 'Grid style 3', 'kiwi' ) => 'gridstyle-three',	
				),			
			//'description' => 'Layout options for navigation.',	
			//'edit_field_class' => 'vc_col-sm-12 vc_column',
			'group' => esc_html__('Design Settings', 'kiwi' ),			
	),
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Hide caption?', 'kiwi' ),
		'param_name' => 'mp_grid_design_layout_hide_caption',
		'description' => esc_html__('Hide title and/or author name.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => 'Design Settings',
		'dependency' => Array( 'element' => 'mp_grid_design_layout', 'value' => Array('gridstyle-two') ),	
		),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Size of the thumbnails', 'kiwi' ),
		'param_name' => 'thumbnail_size',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set thumbnail width (e.g., 80). Numeric only.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'thumbnails-only' ),			
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Size of the thumbnails', 'kiwi' ),
		'param_name' => 'thumbnail_size_height',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set thumbnail height (e.g., 80). Numeric only.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'thumbnails-only' ),			
	),
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Columns', 'kiwi' ),
		'param_name' => 'mp_grid_design_columns',
		'value'       => array(
			esc_html__( 'Select', 'kiwi' ) => '',
			esc_html__( 'One', 'kiwi' ) => 'design_columns_one',
			esc_html__( 'Two', 'kiwi' ) => 'design_columns_two',
			esc_html__( 'Three', 'kiwi' ) => 'design_columns_three',
			esc_html__( 'Four', 'kiwi' ) => 'design_columns_four',					
			),			
		'description' => 'Number of columns inside the grid layout.',	
		//'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array( 'element' => 'mp_grid_design_layout', 'value' => Array('gridstyle-one','gridstyle-two','gridstyle-three') ),	
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt length', 'kiwi' ),
		'param_name' => 'mp_griddesign_excerpt_length',
		'description' => 'E.g. 50',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),
		'value' => '', // default value	
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'gridstyle-one' ),		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt ending', 'kiwi' ),
		'param_name' => 'mp_griddesign_excerpt_ending',
		'description' => 'E.g. ... [dots]',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),
		'value' => '', // default value		
		'edit_field_class' => 'vc_col-sm-6  vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'gridstyle-one' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt link text', 'kiwi' ),
		'param_name' => 'mp_griddesign_excerpt_link',
		'description' => 'E.g. View full description »',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),		
		'value' => ' ', // default value	
		'group' => esc_html__('Design Settings', 'kiwi' ),
		//'edit_field_class' => 'vc_col-sm-12 vc_column-with-padding',
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'gridstyle-one' ),		
	),
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Truncate item title?', 'kiwi' ),
		'param_name' => 'truncate_title',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => 'Design Settings',
		//'edit_field_class' => 'vc_col-sm-12 vc_column-with-padding',
		'dependency' => Array( 'element' => 'mp_grid_design_layout', 'value' => Array('gridstyle-one','gridstyle-two','gridstyle-three') ),		
		),
	
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Length', 'kiwi' ),
			'param_name' => 'grid_truncate_lenght',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( '1 line', 'kiwi' ) => 'one-line',
				esc_html__( '2 lines', 'kiwi' ) => 'two-lines',
				esc_html__( '3 lines', 'kiwi' ) => 'three-lines',
				esc_html__( '4 lines', 'kiwi' ) => 'four-lines',				
				),			
			'description' => '<br />',	
			//'edit_field_class' => 'vc_col-sm-6 vc_column',
			'group' => esc_html__('Design Settings', 'kiwi' ),	
			'dependency' => Array( 'element' => 'truncate_title', 'value' => Array('yes') ),				
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Extra styling?', 'kiwi' ),
		'param_name' => 'mp_author_thumbnail_styling',
		'description' => esc_html__('Enable extra styling.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'thumbnails-only' ),	
		),
		
		
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Tooltip', 'kiwi' ),
		'param_name' => 'mp_tooltip_thumbnails',
		'description' => esc_html__('Enable Preview Tooltip.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'mp_grid_design_layout', 'value' => 'thumbnails-only' ),	
		),



		
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Border', 'kiwi' ),
		'param_name' => 'mp_author_thumbnail_border',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Border e.g.: 1px solid #e8e8e8', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_author_thumbnail_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Padding', 'kiwi' ),
		'param_name' => 'mp_author_thumbnail_padding',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Padding e.g.: 5px 5px 5px 5px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_author_thumbnail_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Background', 'kiwi' ),
		'param_name' => 'mp_author_thumbnail_background',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Background color. E.g.: #ffffff', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_author_thumbnail_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Margin', 'kiwi' ),
		'param_name' => 'mp_author_thumbnail_margin',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Margin. E.g.: 0px 1.4% 1.4% 0px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'mp_author_thumbnail_styling', 'value' => 'yes' ),
	),
		  
	// Data settings
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Order by', 'kiwi' ),
		'param_name' => 'mp_orderby',
		'value' => array(
			esc_html__( 'Date', 'kiwi' ) => 'date',
			esc_html__( 'Order by post ID', 'kiwi' ) => 'ID',
			esc_html__( 'Author', 'kiwi' ) => 'author',
			esc_html__( 'Title', 'kiwi' ) => 'title',
			esc_html__( 'Last modified date', 'kiwi' ) => 'modified',
		//	esc_html__( 'Post/page parent ID', 'kiwi' ) => 'parent',
			esc_html__( 'Number of comments', 'kiwi' ) => 'comment_count',
		//	esc_html__( 'Menu order/Page Order', 'kiwi' ) => 'menu_order',
			esc_html__( 'Meta value', 'kiwi' ) => 'meta_value',
			esc_html__( 'Meta value number', 'kiwi' ) => 'meta_value_num',
		//  esc_html__('Matches same order you passed in via the 'include' parameter.', 'kiwi') => 'post__in'
			esc_html__( 'Random order', 'kiwi' ) => 'rand',
		),
		'description' => esc_html__('Select order type.<br />If "Meta value" or "Meta value Number" is chosen then meta key is required.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		
	),
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Sorting', 'kiwi' ),
		'param_name' => 'mp_sorting',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'Descending', 'kiwi' ) => 'DESC',
			esc_html__( 'Ascending', 'kiwi' ) => 'ASC',
		),
		'description' => esc_html__('Select sorting order.', 'kiwi' ),
				
	),
	 array(
		'type' => 'textfield',
		'heading' => esc_html__('Meta key', 'kiwi' ),
		'param_name' => 'mp_metakey',
		'description' => esc_html__('Input meta key for grid ordering. (e.g., <b>_edd_download_sales</b> for most sales)', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => '',
	), 
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Meta query value', 'kiwi' ),
		'param_name' => 'meta_query_value',
		'description' => esc_html__('Extra filter for meta_key.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => '',		
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Compare', 'kiwi' ),
		'param_name' => 'mp_comparison',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'Equal', 'kiwi' ) => 'EQUAL',
			esc_html__( 'Does not equal', 'kiwi' ) => 'NOT_EQUAL',
			esc_html__( 'Greater than', 'kiwi' ) => 'GREATER_THAN',
			esc_html__( 'Greater than or equal to', 'kiwi' ) => 'GREATER_EQUAL',
			esc_html__( 'Less than', 'kiwi' ) => 'LESS_THAN',
			esc_html__( 'Less than or equal to', 'kiwi' ) => 'LESS_THAN_OR_EQUAL',			
			esc_html__( 'LIKE', 'kiwi' ) => 'LIKE',
			esc_html__( 'NOT LIKE', 'kiwi' ) => 'NOT_LIKE',
			esc_html__( 'IN', 'kiwi' ) => 'IN',
			esc_html__( 'NOT IN', 'kiwi' ) => 'NOT_IN',
			esc_html__( 'BETWEEN', 'kiwi' ) => 'BETWEEN',
			esc_html__( 'NOT BETWEEN', 'kiwi' ) => 'NOT_BETWEEN',
			esc_html__( 'EXISTS', 'kiwi' ) => 'EXISTS',
			esc_html__( 'NOT EXISTS', 'kiwi' ) => 'NOT_EXISTS',
		),
		'description' => esc_html__('Compare settings against specific meta values.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',				
	),	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Offset', 'kiwi' ),
		'param_name' => 'mp_offset',
		'description' => esc_html__('Number of grid elements to displace or pass over.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => 0, // default value		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Exclude categories', 'kiwi' ),
		'param_name' => 'grid_exclude',
		'description' => esc_html__('Exclude categories by adding category id\'s separated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		//'value' => 0, // default value		
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add author parameter', 'kiwi' ),
		'param_name' => 'grid_author_parameter',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => 'Data Settings',
		//'edit_field_class' => 'vc_col-sm-12 vc_column-with-padding',
		//'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_two','grid_style_one','grid_style_three') ),		
		),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Author ID', 'kiwi' ),
		'param_name' => 'grid_author_parameter_id',
		'description' => esc_html__('Enter author ID\'s, seperated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		//'value' => 0, // default value
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array( 'element' => 'grid_author_parameter', 'value' => Array('yes') ),		
	),
	
	
	// Styling settings
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable extra styling?', 'kiwi' ),
		'param_name' => 'grid_extra_styling_box',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
		'dependency' => Array( 'element' => 'mp_grid_design_layout', 'value' => Array('gridstyle-one','gridstyle-two','gridstyle-three') ),	
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable extra heading styling?', 'kiwi' ),
		'param_name' => 'grid_extra_styling_heading_box',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Stretch Full Width', 'kiwi' ),
		'param_name' => 'grid_container_fullwidth_items',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		'description' => esc_html__('Enable this option to stretch your EDD downloads full width.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		//'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
	),
	
		
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Spacing', 'kiwi' ),
		'param_name' => 'grid_spacing_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Spacing inside each grid. (e.g. 5px 10px 5px 10px)', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Spacing', 'kiwi' ),
		'param_name' => 'grid_spacing_box_extra',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Additional spacing around text.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Border color', 'kiwi' ),
		'param_name' => 'grid_border_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Background color', 'kiwi' ),
		'param_name' => 'grid_background_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Title color', 'kiwi' ),
		'param_name' => 'grid_title_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Title hover color', 'kiwi' ),
		'param_name' => 'grid_title_hover_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),	
	
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Excerpt color', 'kiwi' ),
		'param_name' => 'grid_excerpt_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Price color', 'kiwi' ),
		'param_name' => 'grid_price_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Category color', 'kiwi' ),
		'param_name' => 'grid_category_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Category hover color', 'kiwi' ),
		'param_name' => 'grid_category_hover_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Coming Soon color', 'kiwi' ),
		'param_name' => 'grid_coming_soon_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Only works if Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Coming Soon bg color', 'kiwi' ),
		'param_name' => 'grid_coming_soon_background_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Only works if Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
		
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Author text color', 'kiwi' ),
		'param_name' => 'grid_author_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('Text color when Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Author hover color', 'kiwi' ),
		'param_name' => 'grid_author_hover_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('Text color when Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),	
	
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add box shadow?', 'kiwi' ),
		'param_name' => 'grid_shadow_box',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Heading color', 'kiwi' ),
		'param_name' => 'grid_heading_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Heading bg color', 'kiwi' ),
		'param_name' => 'grid_heading_bgcolor_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Heading border color', 'kiwi' ),
		'param_name' => 'grid_heading_border_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Heading padding', 'kiwi' ),
		'param_name' => 'grid_heading_padding_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('E.g. 5px 10px 5px 10px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable full width?', 'kiwi' ),
		'param_name' => 'grid_heading_bg_fullwidth',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'grid_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	
			  
            )
        ) );
    }
    
    /*
    Shortcode logic how it should be rendered
    */
    public function renderMyeddrecent( $atts, $content = null ) {
      extract( shortcode_atts( array(		
		'output' => '',
        'total_items' => '',
        'thumbnail_size' => '',
		'thumbnail_size_height' => '',
		'heading_text' => '',		
		'readmore_link' => '',
		'readmore_text' => '',
		'mp_url_more' => '',
		'mp_sorting' => '',
		'mp_orderby' => '',
		'mp_offset' => '',
		'mp_metakey' => '', 
		'mp_category' => '',
		'categories_array' => '',
		'mp-all-categories' => '',
		'mp_comparison' => '',
		'grid_exclude' => '',
		'meta_query_value' => '',
		'mp_grid_design_layout' => '',
		'mp_grid_design_columns' => '',
		'truncate_title' => '',
		'mp_griddesign_excerpt_length' => '',
		'mp_griddesign_excerpt_ending' => '',
		'mp_griddesign_excerpt_link' => '',		
		'grid_spacing_box' => '',
		'grid_border_box' => '',
		'grid_background_box' => '',
		'grid_shadow_box' => '',
		'grid_spacing_box_extra' => '',
		'grid_extra_styling_box' => '',
		'grid_title_color_box' => '',
		'grid_title_hover_color_box' => '',
		'grid_excerpt_color_box' => '',
		'grid_category_color_box' => '',
		'grid_category_hover_color_box' => '',
		'grid_price_box' => '',
		'grid_coming_soon_box' => '',
		'grid_author_box' => '',
		'grid_author_hover_box' => '',
		'grid_coming_soon_background_box' => '',
		'grid_heading_color_box' => '',
		'grid_heading_bgcolor_box' => '',
		'grid_heading_border_color_box' => '',
		'grid_extra_styling_heading_box' => '',
		'grid_heading_padding_box' => '',
		'grid_heading_bg_fullwidth' => '',
		'mp_grid_design_layout_hide_caption' => '',		
		'mp_author_thumbnail_styling' => '',
		'mp_author_thumbnail_border' => '',
		'mp_author_thumbnail_padding' => '',
		'mp_author_thumbnail_background' => '',
		'mp_author_thumbnail_margin' =>'',
		'mp_grid_pagination' => '',
		'grid_truncate_lenght' => '',
		'truncate_value' => '',
		'grid_author_parameter' => '',
		'grid_author_parameter_id' => '',
		'grid_container_fullwidth_items' => '',
		'mp_grid_pagination_alignment' => '',
		'mp_content_audio' => '',
		'mp_content' => '',	
		'mp_tooltip_thumbnails' => '',		
      ), $atts ) );
     $content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
     
		global $post, $kiwi_theme_option;
		
	if( $grid_container_fullwidth_items == 'yes' ) { 
		$class_full_width_items = ' full-container';
	} else { 
		$class_full_width_items = '';
	}	
	
	if( $mp_grid_pagination == 'yes' ) {
		$store_page_setting = (is_front_page() && is_page_template('page-marketplace.php') ? 'page' : 'paged' );
		$current_page = get_query_var( $store_page_setting );
		$mp_offset = $current_page > 0 ? $total_items * ( $current_page-1 ) : 0;
	}	
		
		$args = array(
			'post_type' 	 => 'download',
			'posts_per_page' => $total_items,
			'post_status'    => 'publish',
			'order'       	 => $mp_sorting,
			'orderby'        => $mp_orderby,			
			'offset' 		 => $mp_offset,		
		);
		
		
		if ( ! empty( $mp_metakey ) ){
			$args['meta_key'] = $mp_metakey;
		}
			
		if( $mp_comparison == 'BETWEEN' || $mp_comparison == 'NOT_BETWEEN' || $mp_comparison == 'NOT_IN' || $mp_comparison == 'IN' ) {
			$value = explode(',', $meta_query_value);
		} else {			
			$value = $meta_query_value;
		} 	
		
		
		// ** ** //
		 if( $meta_query_value !== '') {
		
			 if( $mp_comparison == 'EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => '=',
						'value' => $value,
				);
			 } elseif( $mp_comparison == 'NOT_EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => '!=',
						'value' => $value,
				);
			 } elseif( $mp_comparison == 'GREATER_THAN' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => '>',
						'value' => $value,
				);
			 } elseif($mp_comparison == 'GREATER_EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => '>=',
						'value' => $value,
				);
			 } elseif( $mp_comparison == 'LESS_THAN' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => '<',
						'value' => $value,
				);
			 } elseif($mp_comparison == 'LESS_THAN_OR_EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => '<=',
						'value' => $value,
				);
			 }elseif($mp_comparison == 'NOT_LIKE' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'NOT LIKE',
						'value' => $value,
				);
			 }elseif($mp_comparison == 'NOT_IN' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'NOT IN',
						'value' => $value,
				);
			 } elseif($mp_comparison == 'NOT_BETWEEN' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'NOT BETWEEN',
						'value' => $value,
				);
			 }  elseif($mp_comparison == 'NOT_EXISTS' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'NOT EXISTS',
						'value' => $value,
				);
			 } elseif($mp_comparison == 'LIKE' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'LIKE',
						'value' => $value,
				);
			 } elseif($mp_comparison == 'IN' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'IN',
						'value' => $value,
				);
			 }
			 elseif($mp_comparison == 'BETWEEN' ) { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'BETWEEN',
						'value' => $value,
				);
			 }
			 else { 
				$args['meta_query'][] = array(
						'key'     => $mp_metakey,
						'compare' => 'EXISTS',
						'value' => $value,
				);
			 } 
			 
			 
			 
		 }			 
		 // ** ** //
		 
		
		// if a category is selected
		    if( $mp_category != '' ) {
			$args['tax_query'][] = array(
				'taxonomy'      	 => 'download_category',
				'field'         	 => 'term_id',
				'terms'          	 => $mp_category,
				
			);
		  } 

		// exclude items
		if( $grid_exclude != '' && $mp_category == '' ) {
			$args['tax_query'][] = array(
				'taxonomy'      	 => 'download_category',
				'field'         	 => 'term_id',
				'terms'          	 => explode(',', $grid_exclude),
				'operator' 			 => 'NOT IN'
				
			);
		  }  	
		
		
		if( isset( $grid_author_parameter_id ) && !empty ($grid_author_parameter_id) && $grid_author_parameter = 'yes'  ) {
			$args['author'] = $grid_author_parameter_id;
		}
		
		
		$grid_mp_items = new WP_Query($args); 	
		
		if( $mp_grid_design_columns == 'design_columns_one' ) { 
			$class_column = ' one-columns';
		}elseif( $mp_grid_design_columns == 'design_columns_two' ) { 
			$class_column = ' two-columns';
		}elseif( $mp_grid_design_columns == 'design_columns_three' ) { 
			$class_column = ' three-columns';
		}elseif( $mp_grid_design_columns == 'design_columns_four' ) { 
			$class_column = ' four-columns';
		} else {
			$class_column = '';
		}
		
		
		$uniqid = uniqid('kiwi-');
		
		if( isset( $grid_background_box ) && !empty ($grid_background_box)  ) {
			$value_bg = ' .'.$uniqid.' .grid-view ul li { background:'.$grid_background_box.';} ';
		} else {
			$value_bg = '';
		}
		
		if( isset( $grid_spacing_box ) && !empty ($grid_spacing_box)  ){
			$value_bgpd = ' .'.$uniqid.' .grid-view ul li {  padding:'.$grid_spacing_box.'; }';
		} else {
			$value_bgpd = '';
		}
		
		if( isset( $grid_border_box ) && !empty ($grid_border_box) ){
			$value_bgbr = ' .'.$uniqid.' .grid-view ul li { border:1px solid '.$grid_border_box.' } ';
		} else {
			$value_bgbr = '';
		}
		
				
		if( isset( $grid_spacing_box_extra ) && !empty ($grid_spacing_box_extra)  ) {
			$value_sp = ' .'.$uniqid.' .iso-desc {padding:'.$grid_spacing_box_extra.';} ';
		} else {
			$value_sp = '';
		}
		
		if( isset( $grid_title_color_box ) && !empty ($grid_title_color_box)  ) {
			$value_cl = ' .'.$uniqid.' .grid-view .iso-desc .truncate h4 a, .'.$uniqid.' .grid-view .iso-desc h4 a {color:'.$grid_title_color_box.'} ';
		} else {
			$value_cl = '';
		}
		
		if( isset( $grid_title_hover_color_box ) && !empty ($grid_title_hover_color_box)  ) {
			$value_clh = ' .vc-addon-grid.'.$uniqid.' .mp-vc-items.grid-view .iso-desc .truncate h4 a:hover, .vc-addon-grid.'.$uniqid.' .mp-vc-items.grid-view .iso-desc h4 a:hover {color:'.$grid_title_hover_color_box.'!important} ';
		} else {
			$value_clh = '';
		}			
		
		if( isset( $grid_excerpt_color_box ) && !empty ($grid_excerpt_color_box)  ) {
			$value_ex = ' .'.$uniqid.' .grid-view .excerpt {color:'.$grid_excerpt_color_box.'} ';
		} else {
			$value_ex = '';
		}
		
		if( isset( $grid_category_color_box ) && !empty ($grid_category_color_box)  ) {
			$value_ct = ' .'.$uniqid.' .edd_catlist a {color:'.$grid_category_color_box.'} ';
		} else {
			$value_ct = '';
		}
		
		if( isset( $grid_category_hover_color_box ) && !empty ($grid_category_hover_color_box)  ) {
			$value_cth = ' .'.$uniqid.' .edd_catlist a:hover {color:'.$grid_category_hover_color_box.'} ';
		} else {
			$value_cth = '';
		}
		
		if( isset( $grid_price_box ) && !empty ($grid_price_box)  ) {
			$value_pr = ' .vc-addon-grid.'.$uniqid.' .mp-vc-items.grid-view .item-price {color:'.$grid_price_box.'} ';
		} else {
			$value_pr = '';
		}
		
		if( isset( $grid_coming_soon_box ) && !empty ($grid_coming_soon_box)  ) {
			$value_cm = ' .vc-addon-grid.'.$uniqid.' .mp-vc-items.grid-view .mp-coming-soon{color:'.$grid_coming_soon_box.'!important; } ';
		} else {
			$value_cm = '';
		}
		
		if ( isset( $grid_coming_soon_background_box ) && !empty ($grid_coming_soon_background_box) ){
			$value_cmbg = ' .vc-addon-grid.'.$uniqid.' .mp-vc-items.grid-view .mp-coming-soon{ background:'.$grid_coming_soon_background_box.'!important} ';
		} else {
			$value_cmbg = '';
		}
		
		if( isset( $grid_author_box ) && !empty ($grid_author_box)  ) {
			$value_at = ' .'.$uniqid.' .author a {color:'.$grid_author_box.'!important} ';
		} else {
			$value_at = '';
		}
		
		
		if( isset( $grid_author_hover_box ) && !empty ($grid_author_hover_box)  ) {
			$value_ath = ' .'.$uniqid.' .author a:hover {color:'.$grid_author_hover_box.'!important} ';
		} else {
			$value_ath = '';
		}
		
		if( $grid_shadow_box != '' ) {			
			$value_sha = ' .'.$uniqid.' .grid-view ul li{-webkit-box-shadow: 0px 2px 5px -1px rgba(218, 218, 218, 1); -moz-box-shadow: 0px 2px 5px -1px rgba(218, 218, 218, 1); box-shadow: 0px 2px 5px -1px rgba(218, 218, 218, 1);} ';
		} else {
			$value_sha = '';
		}
		
		
		if( isset( $grid_heading_color_box ) && !empty ($grid_heading_color_box)  ) {
			$value_hdc = ' .'.$uniqid.' .edd_widget_title_vc h3 {color:'.$grid_heading_color_box.';} ';
		} else {
			$value_hdc = '';
		}
		
		if( isset( $grid_heading_bgcolor_box ) && !empty ($grid_heading_bgcolor_box)  ) {
			$value_hdc_bg = ' .'.$uniqid.' .edd_widget_title_vc h3 { background:'.$grid_heading_bgcolor_box.'} ';
		} else {
			$value_hdc_bg = '';
		}
		
		
		if( isset( $grid_heading_border_color_box ) && !empty ($grid_heading_border_color_box)  ) {
			$value_hdbc = ' .'.$uniqid.' .edd_widget_title_vc {background:'.$grid_heading_border_color_box.'} ';
		} else {
			$value_hdbc = '';
		} 
		
		if( isset( $grid_heading_padding_box ) && !empty ($grid_heading_padding_box)  ) {
			$value_hdpadding = ' .'.$uniqid.' .edd_widget_title_vc h3 {padding:'.$grid_heading_padding_box.'; height:auto;line-height:normal;} 
								 .'.$uniqid.' .edd_widget_title_vc {height:auto!important} ';
		} else {
			$value_hdpadding = '';
		} 
		
		if( isset( $grid_heading_bg_fullwidth ) && !empty ($grid_heading_bg_fullwidth)  ) {
			$value_hd_fullwidth = ' .'.$uniqid.' .edd_widget_title_vc h3 {display:block; width:100%} ';
		} else {
			$value_hd_fullwidth = '';
		}
		
		
		
			
$css_style_grid = '<style>
'.$uniqid.' .edd_widget_title_vc {margin-bottom:15px;}
'.$value_bg.' 
'.$value_bgpd.'
'.$value_bgbr.' 
'.$value_sp.'   
'.$value_cl.'   
'.$value_clh.'   
'.$value_ex.'
'.$value_ct.'   
'.$value_cth.'   
'.$value_pr.'   
'.$value_cm.'
'.$value_cmbg.'   
'.$value_at.'
'.$value_ath.'  
'.$value_sha.'
'.$value_hdc.'  
'.$value_hdbc.'
'.$value_hdpadding.'
'.$value_hdc_bg.'
'.$value_hd_fullwidth.'
</style>';
											
				
		if( $grid_extra_styling_box != '' || $grid_extra_styling_heading_box != '' ) {			
			$output .= $css_style_grid;
		}			
		
		$script_style_extra_css = '<style>
					.'.$uniqid.' ul.layout-sorting li {
						background: '.$mp_author_thumbnail_background.';
						border: '.$mp_author_thumbnail_border.';
						padding: '.$mp_author_thumbnail_padding.';
						margin: '.$mp_author_thumbnail_margin.'; 
					}
					</style>';			
		
		if( isset( $mp_author_thumbnail_styling ) && !empty ($mp_author_thumbnail_styling) && $mp_author_thumbnail_styling == 'yes') {
			$output .= $script_style_extra_css;
		} else {
			$output .= '';
		}
		
		/* */
		if( $grid_truncate_lenght == 'one-line' ) {
			$truncate_value = ' one-line';
		} elseif( $grid_truncate_lenght == 'two-lines' ) {
			$truncate_value = ' two-lines';
		}elseif( $grid_truncate_lenght == 'three-lines' ) {
			$truncate_value = ' three-lines';
		}elseif( $grid_truncate_lenght == 'four-lines' ) {
			$truncate_value = ' four-lines';
		} else {
			$truncate_value = ' no';
		}
			
		
		if( $mp_grid_design_layout == 'thumbnails-only' ) {
			$output_divclass = ' design-thumbnails';
		} elseif( $mp_grid_design_layout == 'gridstyle-one' ) {
			$output_divclass = ' design-grid_style_one';
		} elseif( $mp_grid_design_layout == 'gridstyle-two' ) {
			$output_divclass = ' design-grid_style_two';
		}elseif( $mp_grid_design_layout == 'gridstyle-three' ) {
			$output_divclass = ' design-grid_style_three';
		} else {
			$output_divclass = '';
		}
		

		$output .= '<div class="mp-vc-container vc-addon-grid '. esc_attr( $uniqid ).'">';
			
		if( isset( $heading_text ) && !empty ($heading_text)  ) {	
			$output .= "<div class='edd_widget_title_vc'><h3>{$heading_text}</h3></div>";
		}	
			
			
			
		if( $mp_grid_design_layout != '' ) {
			$output .= '<div class="mp-vc-items grid-view'. esc_attr( $class_column ).''. esc_attr( $class_full_width_items ).''. esc_attr( $output_divclass ).'">';
		} else {
			$output .= '<div class="mp-vc-items'.$class_full_width_items.''.$output_divclass.'">';	
		}
		
		
		$output .= '<ul class="layout-sorting">';
		
		$have_results = $grid_mp_items->have_posts();

		if ( !empty( $have_results) && $grid_mp_items->have_posts() ) : while ( $grid_mp_items->have_posts() ) : $grid_mp_items->the_post();
		
		$thumbnails = get_the_ID();
		
		//$griddesign_excerpt = get_the_content();
		$griddesign_excerpt = get_post_field('post_content', get_the_ID());
		$griddesign_excerpt = esc_attr( strip_tags( stripslashes( $griddesign_excerpt ) ) );
		$griddesign_excerpt = preg_replace( '~^(\s*(?:&nbsp;)?)*~i', '', $griddesign_excerpt );
		
				
		$readmore = ''. esc_html( $mp_griddesign_excerpt_ending ).' <a href="' . get_the_permalink() . '">'.esc_html( $mp_griddesign_excerpt_link ).'</a>';
		$griddesign_excerpt = wp_trim_words( $griddesign_excerpt, $num_words = $mp_griddesign_excerpt_length, $more = $readmore );
		
		
		$source = plugins_url( 'images/img-empty-featuredimage.jpg', __FILE__ );
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) ) {	
				
				$coming_soon_cs_active = edd_coming_soon_is_active( get_the_ID() );	
				
				$coming_soon_custom_text = get_post_meta( get_the_ID(), 'edd_coming_soon_text', true );
				$coming_soon_custom_text = !empty ( $coming_soon_custom_text ) ? $coming_soon_custom_text : apply_filters( 'edd_cs_coming_soon_text', esc_html__('Coming Soon', 'edd-coming-soon' ) );
			}
			
		if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
				$constant = EDD_FES()->helper->get_option( 'fes-vendor-constant', '' );
				$constant = ( isset( $constant ) && $constant != '' ) ? $constant : esc_html__( 'vendor', 'kiwi' );
				$constant = apply_filters( 'fes_vendor_constant_singular_lowercase', $constant ); 
			}

		/* */
		if (class_exists( 'EDD_Front_End_Submissions' ) ){ 	

			$fes_featured_video = get_post_meta( get_the_ID(), 'upload_featured_video', true );
			$fes_featured_audio = get_post_meta( get_the_ID(), 'upload_featured_audio', true );

			if ( ! empty( $fes_featured_video ) && empty( $fes_featured_audio ) ) {
				$container_audio = 'mp-thumb-video';
			} elseif ( empty( $fes_featured_video ) && ! empty( $fes_featured_audio ) ) {
				$container_audio = 'mp-thumb-audio';
			} else {
				$container_audio = '';
			}
			
		}		
		
		
			
			$name 			= get_the_author_meta('display_name', $post->post_author);
			$vendor_name	= get_the_author_meta( 'user_login' );
			$avatar			= get_avatar( get_the_author_meta( 'ID' ), 25 );
			
			$edd_catlist 	= get_the_term_list( $post->ID, 'download_category', '', ', ', '' );
			
		
		

if( $mp_grid_design_layout == 'gridstyle-one' ) {	
				
	$output .= "<li>";
	
	$output .= '<div class="iso-thumbnail">';
	
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'.$link.'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink().'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		$output .= '</div>';
		
		
		$output .= '<div class="iso-desc">';
		   
		if( isset( $truncate_title ) && !empty ($truncate_title) && $truncate_title  == 'yes') {
			$output .= '<div class="truncate'. esc_attr( $truncate_value ) .'">';
		} else {
			$output .= '<div>';
		}
		
		$output .= '<h4><a href="'. get_permalink().'">'.get_the_title().'</a></h4>';		
		$output .= '</div>';
		
		$output .= '<div class="excerpt">'.$griddesign_excerpt.'</div>';		
		
		$output .= '<div class="custom-columns">';
		$output .= '<div class="left-column edd_catlist">';
		
		if ( !empty( $edd_catlist ) ){		
		   $output .= $edd_catlist;		
		}
		$output .= '</div>';
		
		$output .= '<div class="right-column align-right">';
		
			if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && $coming_soon_cs_active ) {			
				
			$price = apply_filters( 'edd_coming_soon_display_text', '' . $coming_soon_custom_text . '' );
		
		$output .= sprintf( '<span class="item-price soon">%s</span>', $price );
		
		} else {
			
			remove_filter( 'edd_coming_soon_display_text', 'edd_coming_soon_get_custom_status_text', 30, 2 );
			
			$price = get_post_meta( get_the_ID(), 'edd_price', true );
					
					if ( $price == 0 && $kiwi_theme_option['marketplace-free-enable'] == '1' && !edd_has_variable_prices( get_the_ID() ) ) {
						$output .= '<span class="price free">';
						$price = $kiwi_theme_option['marketplace-free-customtext'];
						$output .= '</span>';
					} elseif ( edd_has_variable_prices( get_the_ID() ) ) {
						 $price = edd_price_range( get_the_ID() );
					} else {
						$price = edd_price( get_the_ID(), false );
					}						 
		$output .= sprintf( '<span class="item-price">%s</span>', $price );	
			
			}
		
		
		$output .= '</div>';
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		
		$output .= '<div class="">';
		$output .= '<div class="left-column mp_author">';
		
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ).'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}	
			
			$output .= '</div>';
			
		$output .= '</div>';
		
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}	
			
		$output .= '<div class="clear"></div>';
		$output .= '</div>';	
	
	
	$output .= '</li>';
			
			
	
} elseif( $mp_grid_design_layout == 'thumbnails-only' ) {

		if( $mp_tooltip_thumbnails == 'yes' && has_post_thumbnail(get_the_ID())) { 
			$force_tool = ' featured-yes';			
		} elseif( $mp_tooltip_thumbnails == 'yes' ) { 
			$force_tool = '';
		} else {
			$force_tool = '';
		}
	
	if (class_exists( 'EDD_Front_End_Submissions' ) ){ 
		if ( ! empty( $fes_featured_video ) && empty( $fes_featured_audio ) ) {
			$output .= "<li class='{$container_audio}{$force_tool}'>";
		} elseif ( empty( $fes_featured_video ) && ! empty( $fes_featured_audio ) ) {
			$output .= "<li class='{$container_audio}{$force_tool}'>";
		} else {
			$output .= "<li class='{$force_tool}'>";
		}
	} else {
		$output .= "<li class='{$force_tool}'>";
	}
		
		//tooltip
		if( $mp_tooltip_thumbnails == 'yes' ) { 
			$tooltip_output = mp_tooltip_effect();		
			$output .= '<div class="mp-vc-tooltip" data-toggle="tooltip" data-container="body" data-placement="auto" title="'. esc_html( $tooltip_output ).'">';
		} 
		
			$mp_featured_value = get_post_meta( get_the_ID(), 'mp_featured_item', true);
			
			if ( $mp_featured_value && $mp_featured_value == 'Yes' ) {	
				$output .= '<div class="featured-item-ribbon"><span></span></div>';				
			}
		
		if ( has_post_thumbnail() ) {
			$output .= '<a href="' . get_the_permalink() . '">';
			
// ****************
if ( class_exists( 'EDD_Front_End_Submissions' ) ) { 
	$vendor_thumbnail = get_post_meta( get_the_ID(), 'upload_item_thumbnail', true );	
}
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !empty( $vendor_thumbnail ) ) { 
				foreach($vendor_thumbnail as $key=>$val){
					$url = wp_get_attachment_image_src( $val, 'full' ); 
					$output .= '<img src="'. esc_url( $url[0] ).'" width="'.$thumbnail_size.'" height="'.$thumbnail_size_height.'">';
				}
			} else {
				$output .= get_the_post_thumbnail( get_the_ID(), array($thumbnail_size, $thumbnail_size_height) );
				
			}	
// ****************					
			
			$output .= "</a>";
		} else { 
			$output .= '<div class="mp-vc-items-single"><a href="' . get_the_permalink() . '">';
			$output .= '<img src="'. esc_url( $source ).'" width="'.$thumbnail_size.'" height="'.$thumbnail_size_height.'">';
			$output .= "</a></div>";
		}

		//tooltip
		if( $mp_tooltip_thumbnails == 'yes' ) { 
			$output .= '</div>';
		}
		
		
		$output .= apply_filters('mp_vc_widget_audio_only', $mp_content_audio);
		
		$output .= '</li>';
		
	} elseif( $mp_grid_design_layout == 'gridstyle-two' ) {
		
		$output .= '<li>';
		
		$output .= '<div class="iso-thumbnail">';		
		
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'.$link.'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink().'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		
		
		$output .= '</div>';
		
		if( isset( $mp_grid_design_layout_hide_caption ) && !empty ($mp_grid_design_layout_hide_caption) && $mp_grid_design_layout_hide_caption  == 'yes') {
				$output .= '';
		} else {	
		$output .= '<div class="iso-desc">';
		$output .= '<div class="truncate'. esc_attr( $truncate_value ).'">';
		$output .= '<h4><a href="'. get_permalink().'">'.get_the_title().'</a></h4>';
		$output .= '</div>';		
	
	
		$output .= '<div class="left-column mp_author">';
		global $post;
			
			$name 			= get_the_author_meta('display_name', $post->post_author);
			$vendor_name	= get_the_author_meta( 'user_login' );
			$avatar			= get_avatar( get_the_author_meta( 'ID' ), 25 );
			
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ).'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}
			
		$output .= '</div>';
		
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right reviews-stylethree">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}
				
		
		}	
		
		$output .= '</li>';
		
		} elseif( $mp_grid_design_layout == 'gridstyle-three' ) {
			
		$output .= '<li>';	
		
		$output .= '<div class="iso-thumbnail">';
		
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'.$link.'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink().'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		$output .= '</div>';
		
		
		$output .= '<div class="iso-desc div-flex">';
		
		if( isset( $truncate_title ) && !empty ($truncate_title) && $truncate_title  == 'yes') {
			$output .= '<div class="left-column align-left truncate'. esc_attr( $truncate_value ).'">';
		} else {
			$output .= '<div class="left-column align-left">';
		}
		
		$output .= '<h4><a href="'. get_permalink().'">'.get_the_title().'</a></h4>';		
		$output .= '</div>';
		
		
		$output .= '<div class="right-column align-right">';
		
			if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && $coming_soon_cs_active ) {			
				
			$price = apply_filters( 'edd_coming_soon_display_text', '' . $coming_soon_custom_text . '' );
		
		$output .= sprintf( '<span class="item-price soon">%s</span>', $price );
		
		} else {
			
			remove_filter( 'edd_coming_soon_display_text', 'edd_coming_soon_get_custom_status_text', 30, 2 );
			
			$price = get_post_meta( get_the_ID(), 'edd_price', true );
					
					if ( $price == 0 && $kiwi_theme_option['marketplace-free-enable'] == '1' && !edd_has_variable_prices( get_the_ID() ) ) {
						$output .= '<span class="price free">';
						$price = $kiwi_theme_option['marketplace-free-customtext'];
						$output .= '</span>';
					} elseif ( edd_has_variable_prices( get_the_ID() ) ) {
						 $price = edd_price_range( get_the_ID() );
					} else {
						$price = edd_price( get_the_ID(), false );
					}						 
		$output .= sprintf( '<span class="item-price">%s</span>', $price );	
			
			}
		
		
		$output .= '</div>';
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		$output .= '<div class="mp_author">';
		
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline"><span class="author vcard">'. esc_html( 'توسط ', 'kiwi').'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ) .'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline"><span class="author vcard">'. esc_html( 'توسط ', 'kiwi').'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}	
		
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right reviews-stylethree">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}		
			
			
		$output .= '</div>';		
		
		$output .= '<div class="clear"></div>';
		$output .= '</li>';
		
		} else {
		$output .= esc_html__('Select layout.', 'kiwi' ); 
	}
	
	

	endwhile;		
		
			$output .= '</ul>';
		
		
		wp_reset_postdata();
		endif;
		
		$output .= "<div class='clear'></div>";			
		$output .= "</div></div>";
		
		
		
		
		$link = '';
		if($readmore_link == "yes" && $mp_url_more != '' ){
				$href = vc_build_link($mp_url_more);
				$link = $href['url'];
				if(isset($href['target'])){
					$target = 'target="'.$href['target'].'"';
				}
				$output .= '<div class="mp-vc-readmore"><a '. esc_attr( $target ).' href="'. esc_url( $link ).'" >';
				$output .= "{$readmore_text}";
				$output .= "</a></div>";
				
			} else {
				
				$output .= '';
		}

	if( $mp_grid_pagination_alignment == 'left' ) {
		$align_class = ' align-left';
	} elseif( $mp_grid_pagination_alignment == 'center' ) {
		$align_class = ' align-center';
	} elseif( $mp_grid_pagination_alignment == 'right' ) {
		$align_class = ' align-right';
	} else {
		$align_class = '';
	}
		
		
	if( $mp_grid_pagination == 'yes' ) {	
		$output .= "<div class='kiwi-pagination{$align_class}'>";							
		$big = 999999999; 					
		$output .= paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, $current_page ),
			'total' => $grid_mp_items->max_num_pages
		) );
		$output .= "</div>";
	}	
		
		return $output;	  
	  
    }

	
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function loadCssAndJs() {
		
		//wp_enqueue_script( 'truncate', plugins_url('js/trunk8.js', __FILE__), array('jquery') );
    }

    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(esc_html__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'kiwi'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new VCExtendAddonClass();