<?php

// don't load directly
if (!defined('ABSPATH')) die('-1');


class VCExtendAddonClassAuthor {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'integrateWithVC' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'eddauthor', array( $this, 'renderMyeddauthor' ) );

        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
    }
 
    public function integrateWithVC() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
		
		 
        vc_map( array(
            "name" => esc_html__("Marketplace :: Author", 'kiwi'),
            "description" => esc_html__("Featured author.", 'kiwi'),
            "base" => "eddauthor",
            "class" => "",
            "controls" => "full",		
            "icon" => "icon-kiwi-author",
			"category" => esc_html__('Theme :: Kiwi', 'kiwi'),
            'admin_enqueue_css' => array(plugins_url('css/kiwi-vc-addon.css', __FILE__)),
			"params" => array(
    
	/* array(
		'type' => 'textfield',
		'heading' => esc_html__('Heading text', 'kiwi' ),
		'param_name' => 'author_heading_text',
		'value' => '', 
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Add title (e.g., Featured Author)', 'kiwi' ),
		
	), */
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Author ID', 'kiwi' ),
		'param_name' => 'author_id',
		'value' => '', 
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Enter the author\'s ID.', 'kiwi' ),
		
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add author description?', 'kiwi' ),
		'param_name' => 'link_authordesc',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add portfolio items?', 'kiwi' ),
		'param_name' => 'link_portfolio',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt length', 'kiwi' ),
		'param_name' => 'mp_author_excerpt_length',
		'description' => 'E.g. 50',
		'value' => '', // default value	
		'edit_field_class' => 'vc_col-sm-6 vc_column',	
		'dependency' => Array('element' => 'link_authordesc', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt ending', 'kiwi' ),
		'param_name' => 'mp_author_excerpt_ending',
		'description' => 'E.g. ... [dots]',
		'value' => '', // default value		
		'edit_field_class' => 'vc_col-sm-6 vc_column',	
		'dependency' => Array('element' => 'link_authordesc', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add author info?', 'kiwi' ),
		'param_name' => 'link_authorinfo',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		'description' => esc_html__('Add info such as <i>joined, website url, portfolio items</i>, etc.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Heading text', 'kiwi' ),
		'param_name' => 'portfolio_heading_text',
		'value' => '', // default value
		'description' => esc_html__('E.g.: Author\'s best selling items.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),
	),
	
	array(        
			'type' => 'dropdown',        
			'heading' => esc_html__('Position', 'kiwi' ),        
			'param_name' => 'portfolio_heading_text_position',  
			'value' => array(
						esc_html__( 'Select', 'kiwi' ) => '',
						esc_html__( 'Above', 'kiwi' ) => 'above',
						esc_html__( 'Below', 'kiwi' ) => 'below',
						),
			'description' => 'Heading text position',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
			'group' => esc_html__('Portfolio Settings', 'kiwi' ),
			'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),	
		),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Total items', 'kiwi' ),
		'param_name' => 'author_total_items',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set max limit for items.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),
	),
	
	array(        
			'type' => 'dropdown',        
			'heading' => esc_html__('Layout style', 'kiwi' ),        
			'param_name' => 'author_layout_style',  
			'value' => array(
						esc_html__( 'Select', 'kiwi' ) => '',
						esc_html__( 'Thumbnails', 'kiwi' ) => 'thumbnails',
						esc_html__( 'Grid style 1', 'kiwi' ) => 'grid_style_one',
						esc_html__( 'Grid style 2', 'kiwi' ) => 'grid_style_two',
						esc_html__( 'Grid style 3', 'kiwi' ) => 'grid_style_three'						
						),
			'description' => 'Under "Data Settings" you can control the sorting options of these portfolio items.',
			'edit_field_class' => 'vc_col-sm-12 vc_column',
			'group' => esc_html__('Portfolio Settings', 'kiwi' ),
			'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),	
		),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Size of the thumbnails', 'kiwi' ),
		'param_name' => 'author_thumbnail_size',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set thumbnail width (e.g., 80). Numeric only.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'author_layout_style', 'value' => 'thumbnails' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Size of the thumbnails', 'kiwi' ),
		'param_name' => 'author_thumbnail_size_height',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set thumbnail height (e.g., 80). Numeric only.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'author_layout_style', 'value' => 'thumbnails' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Extra styling?', 'kiwi' ),
		'param_name' => 'author_thumbnail_styling',
		'description' => esc_html__('Enable extra styling.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',			
		),
		
		array(
		'type' => 'checkbox',
		'heading' => esc_html__('Tooltip', 'kiwi' ),
		'param_name' => 'mp_tooltip_thumbnails',
		'description' => esc_html__('Enable Preview Tooltip.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'author_layout_style', 'value' => 'thumbnails' ),
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Border', 'kiwi' ),
		'param_name' => 'author_thumbnail_border',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Border e.g.: 1px solid #e8e8e8', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'author_thumbnail_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Padding', 'kiwi' ),
		'param_name' => 'author_thumbnail_padding',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Padding e.g.: 5px 5px 5px 5px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'author_thumbnail_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Background', 'kiwi' ),
		'param_name' => 'author_thumbnail_background',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Background color. E.g.: #ffffff', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Portfolio Settings', 'kiwi' ),
		'dependency' => Array('element' => 'author_thumbnail_styling', 'value' => 'yes' ),
	),
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Hide caption?', 'kiwi' ),
		'param_name' => 'mp_author_design_layout_hide_caption',
		'description' => esc_html__('Hide title and/or author name.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => 'Design Settings',
		'dependency' => Array( 'element' => 'author_layout_style', 'value' => Array('grid_style_one') ),	
		),		
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Columns', 'kiwi' ),
		'param_name' => 'mp_author_design_columns',
		'value'       => array(
			esc_html__( 'Select', 'kiwi' ) => '',
			esc_html__( 'One', 'kiwi' ) => 'design_columns_one',
			esc_html__( 'Two', 'kiwi' ) => 'design_columns_two',
			esc_html__( 'Three', 'kiwi' ) => 'design_columns_three',
			esc_html__( 'Four', 'kiwi' ) => 'design_columns_four',					
			),			
		'description' => 'Number of columns inside the grid layout.',	
		//'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array( 'element' => 'author_layout_style', 'value' => Array('grid_style_two','grid_style_one','grid_style_three') ),	
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Truncate item title?', 'kiwi' ),
		'param_name' => 'author_truncate_title',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => 'Design Settings',
		//'edit_field_class' => 'vc_col-sm-12 vc_column-with-padding',
		'dependency' => Array( 'element' => 'author_layout_style', 'value' => Array('grid_style_two','grid_style_one','grid_style_three') ),		
		),
		
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Length', 'kiwi' ),
			'param_name' => 'grid_truncate_lenght',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( '1 line', 'kiwi' ) => 'one-line',
				esc_html__( '2 lines', 'kiwi' ) => 'two-lines',
				esc_html__( '3 lines', 'kiwi' ) => 'three-lines',
				esc_html__( '4 lines', 'kiwi' ) => 'four-lines',				
				),			
			'description' => '<br />',	
			//'edit_field_class' => 'vc_col-sm-6 vc_column',
			'group' => esc_html__('Design Settings', 'kiwi' ),	
			'dependency' => Array( 'element' => 'author_truncate_title', 'value' => Array('yes') ),				
	),
		
		
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt length', 'kiwi' ),
		'param_name' => 'mp_griddesign_author_excerpt_length',
		'description' => 'E.g. 50',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),
		'value' => '', // default value	
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array( 'element' => 'author_layout_style', 'value' => Array('grid_style_two') ),	
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt ending', 'kiwi' ),
		'param_name' => 'mp_griddesign_author_excerpt_ending',
		'description' => 'E.g. ... [dots]',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),
		'value' => '', // default value		
		'edit_field_class' => 'vc_col-sm-6  vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array( 'element' => 'author_layout_style', 'value' => Array('grid_style_two') ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt link text', 'kiwi' ),
		'param_name' => 'mp_griddesign_author_excerpt_link',
		'description' => 'E.g. View full description »',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),		
		'value' => ' ', // default value	
		'group' => esc_html__('Design Settings', 'kiwi' ),
		//'edit_field_class' => 'vc_col-sm-12 vc_column-with-padding',
		'dependency' => Array( 'element' => 'author_layout_style', 'value' => Array('grid_style_two') ),		
	),	
		
		
		
		  
	// Data settings
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Order by', 'kiwi' ),
		'param_name' => 'mp_author_orderby',
		'value' => array(
			esc_html__( 'Date', 'kiwi' ) => 'date',
			esc_html__( 'Order by post ID', 'kiwi' ) => 'ID',
		//	esc_html__( 'Author', 'kiwi' ) => 'author',
			esc_html__( 'Title', 'kiwi' ) => 'title',
			esc_html__( 'Last modified date', 'kiwi' ) => 'modified',
		//	esc_html__( 'Post/page parent ID', 'kiwi' ) => 'parent',
			esc_html__( 'Number of comments', 'kiwi' ) => 'comment_count',
		//	esc_html__( 'Menu order/Page Order', 'kiwi' ) => 'menu_order',
			esc_html__( 'Meta value', 'kiwi' ) => 'meta_value',
			esc_html__( 'Meta value number', 'kiwi' ) => 'meta_value_num',
		//  esc_html__('Matches same order you passed in via the 'include' parameter.', 'kiwi') => 'post__in'
			esc_html__( 'Random order', 'kiwi' ) => 'rand',
		),
		'description' => esc_html__('Select order type.<br />If "Meta value" or "Meta value Number" is chosen then meta key is required.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),
		
	),
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Sorting', 'kiwi' ),
		'param_name' => 'mp_author_sorting',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'Descending', 'kiwi' ) => 'DESC',
			esc_html__( 'Ascending', 'kiwi' ) => 'ASC',
		),
		'description' => esc_html__('Select sorting order.', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),
				
	),
	 array(
		'type' => 'textfield',
		'heading' => esc_html__('Meta key', 'kiwi' ),
		'param_name' => 'mp_author_metakey',
		'description' => esc_html__('Input meta key for grid ordering. (e.g., <b>_edd_download_sales</b> for most sales)', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),
		'value' => '',
	), 
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Offset', 'kiwi' ),
		'param_name' => 'mp_author_offset',
		'description' => esc_html__('Number of grid elements to displace or pass over.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),
		'value' => 0, // default value		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Exclude categories', 'kiwi' ),
		'param_name' => 'mp_author_exclude',
		'description' => esc_html__('Exclude categories by adding category id\'s separated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'dependency' => Array('element' => 'link_portfolio', 'value' => 'yes' ),	
	),
	
			  
            )
        ) );
    }
    
    /*
    Shortcode logic how it should be rendered
    */
    public function renderMyeddauthor( $atts, $content = null ) {
      extract( shortcode_atts( array(
		'output' => '',
		'author_heading_text' => '',
		'author_id' => '',
		'link_authordesc' => '',
		'link_portfolio' => '',
		'link_authorinfo' => '',
		'author_total_items' => '',
		'author_thumbnail_size' => '',
		'author_thumbnail_size_height' => '',
		'author_layout_style' => '',
		'mp_author_orderby' => '',
		'mp_author_sorting' => '',
		'mp_author_metakey' => '',
		'mp_author_offset' => '',
		'mp_author_exclude' => '',
		'mp_author_excerpt_length' => '',
		'mp_author_excerpt_ending' => '',
		'mp_author_excerpt_link' => '',
		'portfolio_heading_text' => '',		
		'mp_author_design_columns' => '',
		'mp_author_design_layout_hide_caption' => '',
		'mp_griddesign_author_excerpt_length' => '',
		'mp_griddesign_author_excerpt_ending' => '',
		'mp_griddesign_author_excerpt_link' => '',
		'author_truncate_title' => '',
		'author_thumbnail_styling' => '',
		'author_thumbnail_border' => '',
		'author_thumbnail_padding' => '',
		'author_thumbnail_background' => '',
		'portfolio_heading_text_position' => '',
		'grid_truncate_lenght' => '',
		'truncate_value' => '',
		'mp_content_audio' => '',
		'mp_content' => '',
		'mp_tooltip_thumbnails' => '',
      ), $atts ) );
     $content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
	 
		global $kiwi_theme_option;
		
		$user_id_author = $author_id;
		$user_info = get_userdata($user_id_author);
		
		$name 			= $user_info->display_name;
		$website 		= $user_info->user_url;
	
		$description1 	= get_the_author_meta( 'description', $user_id_author );
		$description 	= wp_trim_words( $description1, $mp_author_excerpt_length, $mp_author_excerpt_ending );	
		
		$date  			= date_i18n("M d, Y", strtotime(get_the_author_meta('user_registered', $user_id_author)));
		$avatar			= get_avatar( $user_id_author, 80 );
		$post_count 	= count_user_posts( $user_id_author );
		
		$post_author_id 	= get_user_by('id', $user_id_author);
		$post_count 		= count_user_posts( $user_id_author , "download"  );
		
		$source = plugins_url( 'images/img-empty-featuredimage.jpg', __FILE__ );
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) ) {	
				
				$coming_soon_cs_active = edd_coming_soon_is_active( get_the_ID() );	
				
				$coming_soon_custom_text = get_post_meta( get_the_ID(), 'edd_coming_soon_text', true );
				$coming_soon_custom_text = !empty ( $coming_soon_custom_text ) ? $coming_soon_custom_text : apply_filters( 'edd_cs_coming_soon_text', esc_html__('Coming Soon', 'edd-coming-soon' ) );
			}
		
		if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
			$constant = EDD_FES()->helper->get_option( 'fes-vendor-constant', '' );
			$constant = ( isset( $constant ) && $constant != '' ) ? $constant : esc_html__( 'vendor', 'kiwi' );
            $constant = apply_filters( 'fes_vendor_constant_singular_lowercase', $constant ); 
			
			$fes_portfolio 		= EDD_FES()->vendors->get_all_products_count($user_id_author, 'publish'); 
			$vendor_name 		= get_the_author_meta( 'user_login', $user_id_author );
			$vendor_location 	= get_the_author_meta( 'your_location', $user_id_author );
		}

			
		
		/* */
		if( $grid_truncate_lenght == 'one-line' ) {
			$truncate_value = ' one-line';
		} elseif( $grid_truncate_lenght == 'two-lines' ) {
			$truncate_value = ' two-lines';
		}elseif( $grid_truncate_lenght == 'three-lines' ) {
			$truncate_value = ' three-lines';
		}elseif( $grid_truncate_lenght == 'four-lines' ) {
			$truncate_value = ' four-lines';
		} else {
			$truncate_value = ' no';
		}
		/* */
		
		$script_extra_css = '<style>
					.mp-vc-featured-author ul li {
						background: '.$author_thumbnail_background.';
						border: '.$author_thumbnail_border.';
						padding: '.$author_thumbnail_padding.';
					}
					</style>';			
		
		if( isset( $author_thumbnail_styling ) && !empty ($author_thumbnail_styling) && $author_thumbnail_styling  == 'yes') {
			$output .= $script_extra_css;
		} else {
			$output .= '';
		} 
		
			
			if( $mp_author_design_columns == 'design_columns_one' ) { 
				$class_column = ' one-columns';
			}elseif( $mp_author_design_columns == 'design_columns_two' ) { 
				$class_column = ' two-columns';
			}elseif( $mp_author_design_columns == 'design_columns_three' ) { 
				$class_column = ' three-columns';
			}elseif( $mp_author_design_columns == 'design_columns_four' ) { 
				$class_column = ' four-columns';
			} else {
				$class_column = '';
			}
			
			$params = array(
				'post_type' 	 => 'download',
				'posts_per_page' => $author_total_items,
				'post_status'    => 'publish',
				'order'       	 => $mp_author_sorting,
				'orderby'        => $mp_author_orderby,			
				'offset' 		 => $mp_author_offset,
				'meta_key' 		 => $mp_author_metakey,
				'author' 	     => $user_id_author,	
			);
		

		// exclude items
		if( $mp_author_exclude != '' ) {
			$params['tax_query'][] = array(
				'taxonomy'      	 => 'download_category',
				'field'         	 => 'term_id',
				'terms'          	 => explode(',', $mp_author_exclude),
				'operator' 			 => 'NOT IN'				
			);
		  }
			
			 // get the random download
			$grid_mp_items = new WP_Query($params); 			
			
			if( $author_layout_style == 'thumbnails' ) {
				$output_divclass = ' design-thumbnails';
			} elseif( $author_layout_style == 'grid_style_one' ) {
				$output_divclass = ' design-grid_style_one';
			} elseif( $author_layout_style == 'grid_style_two' ) {
				$output_divclass = ' design-grid_style_two';
			}elseif( $author_layout_style == 'grid_style_three' ) {
				$output_divclass = ' design-grid_style_three';
			} else {
				$output_divclass = '';
			}
			
		
			$output .= '<div class="mp-vc-items mp-vc-featured-author'. esc_attr( $output_divclass ).'">';
			
		if( isset( $heading_text ) && !empty ($heading_text)  ) {	
			$output .= "<div class='edd_widget_title_vc'><h3>{$heading_text}</h3></div>";
		}	
			
		$output .=  '<div class="row">';	
		$output .=  '<div class="col-md-6 col-sm-6 col-xs-12 first-column">';
		$output .=  '<div class="author intro">';
			
				$output .=  '<div class="author-avatar-left">';
				
				$output .=  '<div class="author-avatar">'.$avatar.'</div>';
				
				if($link_authorinfo == "yes" && $link_authorinfo != '' ){		

					if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
						$output .= '<a class="portfolio-link" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html__( 'View Portfolio', 'edd' ).'</a>';
					} 
				}
				
				$output .=  '</div>'; 
			
			
			
			if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	 
				$output .=  '<h4><a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ).'</a></h4>'; 
			} else {
				$output .=  '<h4 rel="author">'. esc_html( $name ) .'</h4>';
			}
			
			$output .= '<div class="author-location">';	
						
				if ( isset($vendor_location) && !empty( $vendor_location ) ) {
					$output .= '<i class="fa fa-map-marker"></i> '. esc_html( $vendor_location ).'</span>';
				} else {
					$output .= '';
				}	
			
			$output .= '</div>';
		
		
if($link_authordesc == "yes" && $link_authordesc != '' ){	
		$output .=  '<div class="author-desc">'. esc_html( $description ).'</div>';
}

			$output .= '</div><div class="clear"></div>';
			
			$output .= '<div class="author-stats">';
			
if($link_authorinfo == "yes" && $link_authorinfo != '' ){		

	 	
	$output .= '<div class="row">
				<div class="stats-finance">	';	
				
	global $kiwi_theme_option;			
				
if ( $kiwi_theme_option['miscellaneous-vc-rtl-support'] == '1' ) {
				
	$output .= '<div class="col-md-4 col-sm-4 col-xs-4 mp-third">
		<div class="result text-due">'. esc_html__( 'Website', 'edd' ).'</div>
		<div class="result text-subline"><a href="'. esc_url( $website ).'" target="_blank">'. esc_html__( 'Link', 'kiwi' ).'</a></div>			
	</div>	';
	
	$output .= '<div class="col-md-4 col-sm-4 col-xs-4 mp-second">';
	
		if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
			$output .=  '<div class="result text-due">'. esc_html__( 'Portfolio', 'edd' ).'</div>
			<div class="result text-subline">'. esc_html( $fes_portfolio ) .' <span>'._n( 'محصول', 'محصول', esc_html( $fes_portfolio ), 'kiwi' ).'</div>';
		} else {
			$output .=  '<div class="result text-due">'. esc_html__( 'Portfolio', 'edd' ).'</div>
			<div class="result text-subline">'. esc_html( $post_count ).' <span>'._n( 'محصول', 'محصول', esc_html( $post_count ), 'kiwi' ).'</div>	';
		}
		
	$output .= '</div>';
				
	$output .= '<div class="col-md-4 col-sm-4 col-xs-4">
				<div class="result text-due">'. esc_html__( 'Joined on', 'edd' ).'</div>
				<div class="result text-subline">'. esc_attr( $date ).'</div>
			</div>';
	
} else {
	
	$output .= '<div class="col-md-4 col-sm-4 col-xs-4">
					<div class="result text-due">'.esc_html__( 'Joined on', 'edd' ).'</div>
					<div class="result text-subline">'. esc_attr( $date ).'</div>
				</div>';
				
				
	$output .= '<div class="col-md-4 col-sm-4 col-xs-4 mp-second">';
	
		if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
			$output .=  '<div class="result text-due">'. esc_html__( 'Portfolio', 'edd' ).'</div>
			<div class="result text-subline">'. esc_html( $fes_portfolio ).' <span>'._n( 'محصول', 'محصول',  esc_html( $fes_portfolio ), 'kiwi' ).'</div>';
		} else {
			$output .=  '<div class="result text-due">'. esc_html__( 'Portfolio', 'edd' ).'</div>
			<div class="result text-subline">'. esc_html( $post_count ).' <span>'._n( 'محصول', 'محصول',  esc_html( $post_count ), 'kiwi' ).'</div>	';
		}
		
	$output .= '</div>';
				
	$output .= '<div class="col-md-4 col-sm-4 col-xs-4 mp-third">
		<div class="result text-due">'.esc_html__( 'Website', 'edd' ).'</div>
		<div class="result text-subline"><a href="'. esc_url( $website) .'" target="_blank">'. esc_html__( 'Link', 'kiwi' ).'</a></div>			
	</div>	';
	
}			
	
	$output .= '</div>	
</div>';
	
}			
			
			
			
			$output .=  '<div class="clear"></div>';
			$output .=  '</div>';
			
			$output .=  '</div>';
			
			
		
			
			$output .=  '<div class="col-md-6 col-sm-6 col-xs-12 second-column">';
			
			
	if($link_portfolio == "yes" && $link_portfolio != '' ){
	
		if( isset( $portfolio_heading_text ) && !empty ($portfolio_heading_text) && $portfolio_heading_text_position == "above" ) {	
			$output .= "<h4 class='port-title{$class_column}'>{$portfolio_heading_text}</h4>";
		}	
		
		$output .= "<div class='mp-vc-items grid-view{$class_column}'>";		
		
			$output .= "<ul class='layout-sorting'>";
			
			$have_results = $grid_mp_items->have_posts();
			if ( !empty( $have_results) && $grid_mp_items->have_posts() ) : while ( $grid_mp_items->have_posts() ) : $grid_mp_items->the_post();
			
			//$griddesign_excerpt = get_the_content();
			$griddesign_excerpt = get_post_field('post_content', get_the_ID());
			$griddesign_excerpt = esc_attr( strip_tags( stripslashes( $griddesign_excerpt ) ) );
			$griddesign_excerpt = preg_replace( '~^(\s*(?:&nbsp;)?)*~i', '', $griddesign_excerpt );
			
					
			$readmore = ''. esc_html( $mp_griddesign_author_excerpt_ending ).' <a href="' . get_the_permalink() . '">'. esc_html( $mp_griddesign_author_excerpt_link ).'</a>';
			$griddesign_excerpt = wp_trim_words( $griddesign_excerpt, $num_words = $mp_griddesign_author_excerpt_length, $more = $readmore );
			
			$edd_catlist 	= get_the_term_list( get_the_ID(), 'download_category', '', ', ', '' );

			/* */
			if (class_exists( 'EDD_Front_End_Submissions' ) ){ 
				$fes_featured_video = get_post_meta( get_the_ID(), 'upload_featured_video', true );
				$fes_featured_audio = get_post_meta( get_the_ID(), 'upload_featured_audio', true );

				if ( ! empty( $fes_featured_video ) && empty( $fes_featured_audio ) ) {
					$container_audio = ' mp-thumb-video';
				} elseif ( empty( $fes_featured_video ) && ! empty( $fes_featured_audio ) ) {
					$container_audio = ' mp-thumb-audio';
				} else {
					$container_audio = '';
				}
			}
			
			if( $mp_tooltip_thumbnails == 'yes' && has_post_thumbnail(get_the_ID())) { 
				$force_tool = ' featured-yes';			
			} elseif( $mp_tooltip_thumbnails == 'yes' ) { 
				$force_tool = '';
			} else {
				$force_tool = '';
			}
			
			
			if( $author_layout_style == 'thumbnails' ) {
				$output .= "<li class='{$container_audio}{$force_tool}'>";
			} else {
				$output .= "<li class='{$force_tool}'>";
			}
		
	
		if( $author_layout_style == 'thumbnails' ) { 
		
	
		//tooltip
		if( $mp_tooltip_thumbnails == 'yes' ) { 
			$tooltip_output = mp_tooltip_effect();		
			$output .= '<div class="mp-vc-tooltip" data-toggle="tooltip" data-container="body" data-placement="auto" title="'. esc_html( $tooltip_output ).'">';
		} 
	
	
			$mp_featured_value = get_post_meta( get_the_ID(), 'mp_featured_item', true);
			
			if ( $mp_featured_value && $mp_featured_value == 'Yes' ) {	
				$output .= '<div class="featured-item-ribbon"><span></span></div>';				
			}
			
			if ( function_exists( 'has_post_thumbnail' ) && has_post_thumbnail( get_the_ID() ) ) {
				
				$output .= '<a href="' . get_permalink( get_the_ID() ) . '">';
				
			// ****************
			if ( class_exists( 'EDD_Front_End_Submissions' ) ) { 
				$vendor_thumbnail = get_post_meta( get_the_ID(), 'upload_item_thumbnail', true );	
			}
				if ( class_exists( 'EDD_Front_End_Submissions' ) && !empty( $vendor_thumbnail ) ) { 
					foreach($vendor_thumbnail as $key=>$val){
						$url = wp_get_attachment_image_src( $val, 'full' ); 
						$output .= '<img src="'. esc_url( $url[0] ).'" width="'.$author_thumbnail_size.'" height="'.$author_thumbnail_size_height.'">';
					}
				} else {
					$output .= get_the_post_thumbnail( get_the_ID(), array($author_thumbnail_size, $author_thumbnail_size_height) );					
				}	
			// ****************					
				
				$output .= "</a>";
			} else { 
				$output .= '<a href="' . get_permalink( get_the_ID() ) . '">';
				$output .= '<img src="'. esc_url( $source ).'" width="'.$author_thumbnail_size.'" height="'.$author_thumbnail_size_height.'">';
				$output .= "</a>";
			}

			//tooltip
			if( $mp_tooltip_thumbnails == 'yes' ) { 
				$output .= '</div>';
			}	
			
			$output .= apply_filters('mp_vc_widget_audio_only', $mp_content_audio);
				 
	} elseif( $author_layout_style == 'grid_style_one' ) { 
		
		
		$output .= '<div class="iso-thumbnail">';
				
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'.$link.'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink( get_the_ID() ) .'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		
		
		$output .= '</div>';
		
		if( isset( $mp_author_design_layout_hide_caption ) && !empty ($mp_author_design_layout_hide_caption) && $mp_author_design_layout_hide_caption == 'yes') {
			$output .= '';
		} else {	
			$output .= '<div class="iso-desc">';
			$output .= '<div class="truncate'.  esc_attr( $truncate_value ).'">';
			$output .= '<h4><a href="'. get_permalink( get_the_ID() ) .'">'.get_the_title(get_the_ID()).'</a></h4>';
			$output .= '</div>';		
			
			$output .= '<div class="left-column mp_author">';	
				if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
						$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
						$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ) .'</a>'; 
						$output .= '</span></span>';
					} else {					
						$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
						$output .= esc_html( $name ); 
						$output .= '</span></span>';
				}
			$output .= '</div>';
			
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}
			
			$output .= '</div>';
			
			
		
		
		}
		
	} elseif( $author_layout_style == 'grid_style_two' ) { 
		
		
		$output .= '<div class="iso-thumbnail">';
		
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'.$link.'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink( get_the_ID() ) .'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		
		$output .= '</div>';
		
		
		$output .= '<div class="iso-desc">';
		
		   
		if( isset( $author_truncate_title ) && !empty ($author_truncate_title) && $author_truncate_title == 'yes') {
			$output .= '<div class="truncate'. esc_attr( $truncate_value ).'">';
		} else {
			$output .= '<div>';
		}
		
		$output .= '<h4><a href="'. get_permalink( get_the_ID()  ).'">'.get_the_title(get_the_ID()).'</a></h4>';		
		$output .= '</div>';
		
		$output .= '<div class="excerpt">'.$griddesign_excerpt.'</div>';
		
		
		$output .= '<div class="custom-columns">';
		$output .= '<div class="left-column edd_catlist">';
		
		if ( !empty( $edd_catlist ) ){		
		   $output .= $edd_catlist;		
		}
		$output .= '</div>';
		
		$output .= '<div class="right-column align-right">';
		
			if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && $coming_soon_cs_active ) {			
				
			$price = apply_filters( 'edd_coming_soon_display_text', '' . $coming_soon_custom_text . '' );
		
		$output .= sprintf( '<span class="item-price soon">%s</span>', $price );
		
		} else {
			
			remove_filter( 'edd_coming_soon_display_text', 'edd_coming_soon_get_custom_status_text', 30, 2 );
			
			$price = get_post_meta( get_the_ID(), 'edd_price', true );
					
								if ( $price == 0 && $kiwi_theme_option['marketplace-free-enable'] == '1' && !edd_has_variable_prices( get_the_ID() ) ) {
									$output .= '<span class="price free">';
										$price = $kiwi_theme_option['marketplace-free-customtext'];
									$output .= '</span>';
								} elseif ( edd_has_variable_prices( get_the_ID() ) ) {
									 $price = edd_price_range( get_the_ID() );
								} else {
									$price = edd_price( get_the_ID(), false );
								}						 
		$output .= sprintf( '<span class="item-price">%s</span>', $price );	
			
			}
		
		
		$output .= '</div>';
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		
		$output .= '<div class="">';
		$output .= '<div class="left-column mp_author">';
		
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ) .'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline"><span class="author vcard">'.$avatar.'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}	
			
			$output .= '</div>';
			
		$output .= '</div>';		
		
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}	
		
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
				
		
	} elseif( $author_layout_style == 'grid_style_three' ) { 
		
		$output .= '<div class="iso-thumbnail">';
				
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
				
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'.$link.'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink( get_the_ID() ) .'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		
		$output .= '</div>';
		
		
		$output .= '<div class="iso-desc div-flex">';
		
		   
		if( isset( $author_truncate_title ) && !empty ($author_truncate_title) && $author_truncate_title == 'yes') {
			$output .= '<div class="left-column align-left truncate'. esc_attr( $truncate_value ).'">';
		} else {
			$output .= '<div class="left-column align-left">';
		}
		
		$output .= '<h4><a href="'. get_permalink( get_the_ID()  ).'">'.get_the_title(get_the_ID()).'</a></h4>';		
		$output .= '</div>';
		
		
		$output .= '<div class="right-column align-right">';
		
			if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && $coming_soon_cs_active ) {			
				
			$price = apply_filters( 'edd_coming_soon_display_text', '<p><strong>' . $coming_soon_custom_text . '</strong></p>' );
		
		$output .= sprintf( '<span class="item-price soon">%s</span>', $price );
		
		} else {
			
			remove_filter( 'edd_coming_soon_display_text', 'edd_coming_soon_get_custom_status_text', 30, 2 );
			
			$price = get_post_meta( get_the_ID(), 'edd_price', true );
					
								if ( $price == 0 && $kiwi_theme_option['marketplace-free-enable'] == '1' && !edd_has_variable_prices( get_the_ID() ) ) {
									$output .= '<span class="price free">';
										$price = $kiwi_theme_option['marketplace-free-customtext'];
									$output .= '</span>';
								} elseif ( edd_has_variable_prices( get_the_ID() ) ) {
									 $price = edd_price_range( get_the_ID() );
								} else {
									$price = edd_price( get_the_ID(), false );
								}						 
		$output .= sprintf( '<span class="item-price">%s</span>', $price );	
			
			}
		
		
		$output .= '</div>';
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		
		$output .= '<div class="mp_author">';
		
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline"><span class="author vcard">'.__('by ', 'kiwi').'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ).'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline"><span class="author vcard">'.__('by ', 'kiwi').'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}	
			
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right reviews-stylethree">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}	
			
			
		
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		
	} else {
		$output .= '';
	}	 		 
		

		
		$output .= '</li>';			
	
			
			endwhile;		
		
		
		$output .= '</ul>';	
		wp_reset_postdata();
		
		endif;
		
		$output .= '</div>';

	if( isset( $portfolio_heading_text ) && !empty ($portfolio_heading_text) && $portfolio_heading_text_position == "below" ) {	
			$output .= "<div class='clear'></div><h4 class='port-title{$class_column}'>{$portfolio_heading_text}</h4>";
		}		
				 
}

			$output .= "<div class='clear'></div>";	
			$output .=  '</div>';
		
		$output .= "</div></div>";
		
		return $output;	  
	  
    }

    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function loadCssAndJs() {
		//wp_enqueue_script( 'truncate', plugins_url('js/trunk8.js', __FILE__), array('jquery') );
    }

    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(esc_html__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'kiwi'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new VCExtendAddonClassAuthor();