<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://theme-kiwi.com
 * @since      1.0.0
 *
 * @package    Marketplace_Edd_Vcaddons
 * @subpackage Marketplace_Edd_Vcaddons/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Marketplace_Edd_Vcaddons
 * @subpackage Marketplace_Edd_Vcaddons/public
 * @author     Kiarashi <no@spam.com>
 */
class Marketplace_Edd_Vcaddons_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Marketplace_Edd_Vcaddons_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Marketplace_Edd_Vcaddons_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/marketplace-edd-vcaddons-public.css', array(), $this->version, 'all' );
		
		global $edd_options;
		
		wp_register_style( 'kiwi-styling-slickslider', plugin_dir_url( __FILE__ ) . 'css/slick.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'kiwi-styling-slickslider'); 		
		
		if( class_exists( 'Easy_Digital_Downloads' ) && edd_get_option( 'mp_vc_demo_style_enbale', false ) == true ) {			
			wp_register_style('kiwi-styling-demo', plugin_dir_url( __FILE__ ) . 'css/mp-vc-demo.css', array(), $this->version, 'all' );
			wp_enqueue_style('kiwi-styling-demo');			
		} 
		
		wp_register_style('kiwi-styling-fontawesome', plugin_dir_url( __FILE__ ) . 'css/font-awesome.min.css', array(), $this->version, 'all' );
		wp_enqueue_style('kiwi-styling-fontawesome');
		
		wp_register_style('kiwi-styling-bootstrap', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );
		wp_enqueue_style('kiwi-styling-bootstrap');
		
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Marketplace_Edd_Vcaddons_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Marketplace_Edd_Vcaddons_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/marketplace-edd-vcaddons-public.js', array( 'jquery' ), $this->version, false );
		
		wp_register_script( 'kiwi-bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'kiwi-bootstrap'); 
				
		wp_register_script( 'kiwi-mixitup', plugin_dir_url( __FILE__ ) . 'js/jquery.mixitup.min.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'kiwi-mixitup'); 
		
		wp_register_script( 'kiwi-slickslider', plugin_dir_url( __FILE__ ) . 'js/slick.min.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'kiwi-slickslider'); 
		
		wp_register_script( 'kiwi-truncate', plugin_dir_url( __FILE__ ) . 'js/trunk8.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'kiwi-truncate'); 
		
		wp_register_script( 'kiwi-match-heights', plugin_dir_url( __FILE__ ) . 'js/jquery.matchHeight-min.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'kiwi-match-heights'); 
		
	}
	
	
	/**
	 * Register the Visual Composer Addons
	 *
	 * @since    1.0.0
	 */
	
	public function kiwi_vc_addons() {
		
		if( class_exists( 'Easy_Digital_Downloads' ) && class_exists('Vc_Manager') ) {         
		
			// register widgets	
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd.php';
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_author.php';
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_categoryblock.php';
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_filter.php';
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_post.php';
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_slider.php';
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_include.php';
			
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/edd-themes/vc_mp_edd_include_custom_themes.php';
			
			if ( class_exists( 'EDD_Front_End_Submissions' ) ) { 	
				require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/vc_mp_edd_vendors.php';
			}	
		
		}
		
	}	
	
}
