<?php

// don't load directly
if (!defined('ABSPATH')) die('-1');


class VCExtendAddonClassCategoryBlock {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'integrateWithVC' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'kiwiloader', array( $this, 'renderMykiwiloader' ) );

        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
    }
 
    public function integrateWithVC() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }
		
		$wpkses = array(
			'br' => array(),
			'em' => array(),
			'strong' => array(),
			'small' => array(),
			'b' => array(),
			'i' => array(),
			'u' => array(),
		);
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
		
$categories_array = array( esc_html__('Select', 'kiwi' ) => '' );
$category_list = get_terms( 'download_category', array( 'hide_empty' => false ) );

	if ( is_array( $category_list ) && ! empty( $category_list ) ) {
		foreach ( $category_list as $category_details ) {	
			$begin = __(' (ID: ', 'kiwi');
			$end = __(')', 'kiwi');
			$categories_array[ $category_details->name . $begin. $category_details->term_id . $end ] = $category_details->term_id;	
		}
	} 		 
        vc_map( array(
            "name" => esc_html__("Maketplace :: Category", 'kiwi'),
            "description" => esc_html__("Create a category block", 'kiwi'),
            "base" => "kiwiloader",
            "class" => "",
            "controls" => "full",		
            "icon" => "icon-kiwi-cat",
			"category" => esc_html__('EDD', 'kiwi'),
           // 'admin_enqueue_css' => array(plugins_url('../css/kiwi-vc-addon.css', __FILE__)),
			"params" => array(
    
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Heading', 'kiwi' ),
		'param_name'       => 'kiwi_heading_cat',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	array(
			'type' => 'dropdown',
			//'heading' => esc_html__('Select heading', 'kiwi' ),
			'param_name' => 'subcat_options',
			'value'       => array(
						esc_html__( 'Select heading', 'kiwi' ) => '',
						esc_html__( 'Categories', 'kiwi' ) => 'options-categories',
						esc_html__( 'Custom', 'kiwi' ) => 'options-custom',				
						),					
			'description' => esc_html__('Filter based on categories or custom field.', 'kiwi' ),			
	), 
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Custom Heading', 'kiwi' ),
		'param_name'       => 'kiwi_heading_custom',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Custom', 'kiwi' ),
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-custom' ),
	),
	array(
			'type' => 'textfield',
			'heading' => esc_html__('Title', 'kiwi' ),
			'param_name' => 'options_custom_heading',
			'value' => '', 
			//'param_holder_class' => 'vc_not-for-custom',
			'description' => esc_html__('E.g.: Best Sellers', 'kiwi' ),
			'group' => esc_html__('Custom', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
			'dependency' => Array('element' => 'subcat_options', 'value' => 'options-custom' ),
	), 
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add custom link?', 'kiwi' ),
		'param_name' => 'options_custom_link',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Custom', 'kiwi' ),
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-custom' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Read more text link', 'kiwi' ),
		'param_name' => 'options_custom_readmore_text',
		'value' => '', // default value
		'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('(e.g., View more items in this category).', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Custom', 'kiwi' ),
		'dependency' => Array('element' => 'options_custom_link', 'value' => 'yes' ),
	),
		
	
	array(
		'type' => 'vc_link',
		'heading' => esc_html__('Add url here', 'kiwi' ),
		'param_name' => 'options_custom_url_more',
		'value' => '',
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Custom', 'kiwi' ),
		'dependency' => Array('element' => 'options_custom_link', 'value' => 'yes' ),
	),
	
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Select Category', 'kiwi' ),
		'param_name' => 'subcat_category',
		'value' => $categories_array,			
		'description' => esc_html__('Select category.', 'kiwi' ),
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-categories' ),
	),
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Subheading', 'kiwi' ),
		'param_name'       => 'kiwi_subheading_cat',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Subheading', 'kiwi' ),
		'param_name' => 'subcat_heading_text',
		'value' => '', 
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('(optional)', 'kiwi' ),
		
	),
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Category Settings', 'kiwi' ),
		'param_name'       => 'kiwi_cat_settings_field',
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-categories' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Show subcategory?', 'kiwi' ),
		'param_name' => 'show_subcat',
		//'description' => esc_html__('Hide title and/or author name.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-categories' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		),

	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Show category count?', 'kiwi' ),
		'param_name' => 'show_catcount',
		//'description' => esc_html__('Hide title and/or author name.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-categories' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		),	
		
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Number of subcategories', 'kiwi' ),
		'param_name' => 'total_subcat',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set max. number of items inside your carousel.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'show_subcat', 'value' => 'yes' ),
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Exclude subcategories', 'kiwi' ),
		'param_name' => 'exclude_subcat',
		'description' => esc_html__('Exclude categories by adding category id\'s separated by a comma.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'show_subcat', 'value' => 'yes' ),		
	),
	
	
	
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Author Settings', 'kiwi' ),
		'param_name'       => 'kiwi_heading_author_set',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Number of authors', 'kiwi' ),
		'param_name' => 'limit_author',
		'description' => esc_html__('Max number of avatars from authors to display. ', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		//'dependency' => Array('element' => 'show_subcat', 'value' => 'yes' ),		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Button text', 'kiwi' ),
		'param_name' => 'subcat_button_text',
		'description' => esc_html__('E.g.: View all items inside this category.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'subcat_options', 'value' => 'options-categories' ),	
	),
	
	
	
			  
            )
        ) );
    }
    
    /*
    Shortcode logic how it should be rendered
    */
    public function renderMykiwiloader( $atts, $content = null ) {
      extract( shortcode_atts( array(
		'output' => '',
		'subcat_category' => '',
		'subcat_heading_text' => '',
		'show_subcat' => '',
		'total_subcat' => '',
		'exclude_subcat' => '',
		'limit_author' => '',
		'subcat_button_text' => '',
		'subcat_options' => '',
		'options_custom_heading' => '',
		'show_catcount' => '',
		'options_custom_link' => '',
		'options_custom_readmore_text' => '',
		'options_custom_url_more' => '',
      ), $atts ) );
     $content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
     
	 
		$args = array(
			'show_option_all'    => '',
			'orderby'            => 'name',
			'order'              => 'ASC',
			'style'              => 'list',
			'hide_empty'         => true,
			'child_of'           => $subcat_category,			
			'exclude'          	=> explode(',', $exclude_subcat),			
			'title_li'           => '',
			'number'             => $total_subcat,
			);
						
	$terms = get_terms( 'download_category', $args );			
	
	$quantityTermObject = get_term_by( 'id', absint( $subcat_category ), 'download_category' );
	
if ( !empty ( $quantityTermObject) ) {	
	$quantityTermName = $quantityTermObject->name;
	$quantityTermCount = $quantityTermObject->count;
	$quantityTermSlug = $quantityTermObject->slug;
} 
	 
	$output .= "<div class='mp-vc-items kiwi-edd-category-block'>";
	
if( $subcat_options == 'options-custom' ) {	
	$output .= "<div class='cat-name'>{$options_custom_heading}</div>";	
} else {
	
	if ( !empty ( $quantityTermObject) ) {	
		$output .= '<div class="cat-name">'. esc_html( $quantityTermName ).'</div>';
	}
	
}
	
		$output .= "<div class='cat-subtitle'>{$subcat_heading_text}</div>";
		
		if( isset( $show_subcat ) && !empty ($show_subcat) && $show_subcat  == 'yes' && $terms) {
			$output .= '<ul class="subcatlist">';
				foreach ($terms as $term) {
					$output .= '<li><a href="'. esc_url( get_term_link($term) ).'">'. esc_html( $term->name ) .'</a></li>';
				}
			$output .= '</ul>';
		
		} else {
			$output .= '';
		}
	

	if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
			$constant = EDD_FES()->helper->get_option( 'fes-vendor-constant', '' );
			$constant = ( isset( $constant ) && $constant != '' ) ? $constant : esc_html__( 'vendor', 'kiwi' );
            $constant = apply_filters( 'fes_vendor_constant_singular_lowercase', $constant ); 			
	}

	
		$catcount_title = esc_html__('تمام محصولات موجود در این دسته:', 'kiwi' );
		
		if($show_catcount == "yes" && !empty ( $quantityTermCount) ) {
			$output .= '<div class="total-items">'. esc_html( $catcount_title ).'<span>'. esc_html( $quantityTermCount ).'</span></div>';
		}
		
		
	$output .= "<div class='authors'>";
	
			//$current_category = single_cat_title("", false);
			$author_array = array();
				$args = array(
					'numberposts' => -1,
					'post_type' => 'download',
					'posts_per_page'   => $limit_author,
					'orderby' => 'random',
					'order' => 'ASC',
					'post_status' => 'publish',
					'tax_query' => array(
							array(
								'taxonomy' => 'download_category',
								'field' => 'term_id',
								'terms' => $subcat_category
							)
						),
				);
			$cat_posts = get_posts($args);
			
			
		if ( $cat_posts	) {
			
			foreach ($cat_posts as $cat_post) :
				if (!in_array($cat_post->post_author,$author_array)) {
					$author_array[] = $cat_post->post_author;
				}
			endforeach;
			
			foreach ($author_array as $author) :
				$auth = get_userdata($author)->display_name;
				$auth_link = get_userdata($author)->user_login;
				$auth_avatarid = get_userdata($author)->ID;
				$avatar = get_avatar( $auth_avatarid, 32 );
				
			if ( class_exists( 'EDD_Front_End_Submissions' ) ) {					 
				$vendor_name = get_the_author_meta( 'user_login' );
				$output .= '<span><a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $auth_link) ).'">'.$avatar.'</a></span>';
			} else {
				$output .= '<span rel="author">'.$avatar.'</span>';
			}
			
			endforeach; 
			
			

		}	
		
	$output .= "</div>";
	
		wp_reset_postdata();
		
		
		$link = '';
		if($options_custom_link == "yes" && $options_custom_url_more != '' && $subcat_options == 'options-custom'){
				$href = vc_build_link($options_custom_url_more);
				$link = $href['url'];
				if(isset($href['target'])){
					$target = 'target="'.$href['target'].'"';
				}
				
				if ( !empty ( $quantityTermObject) ) {		
					$output .= '<a '.$target.' class="mp-category-button" href="'. esc_url( $link ).'" >';
					$output .= "{$options_custom_readmore_text}";
					$output .= "</a>";
				}
			
			} else {
				
			if($subcat_button_text != '' ){	
			
				if ( defined( 'EDD_SLUG' ) ) {
					$slug = EDD_SLUG.'/category';
				} else {
					$slug = 'downloads/category';
				}				
			
				if ( !empty ( $quantityTermObject) ) {			
					$output .= '<a class="mp-category-button" href="' . esc_url( site_url().'/'. $slug .'/'. $quantityTermSlug ) . '">';
					$output .= "{$subcat_button_text}";
					$output .= '</a>';
				}	
				
			}	
		}	
		
	$output .= "</div>";
	
		return $output;	  
	  
    }

    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function loadCssAndJs() {
    //  wp_register_style( 'vc_extend_style', plugins_url('assets/vc_extend.css', __FILE__) );
	// wp_enqueue_style( 'slick-slider-css', get_template_directory_uri() . '/css/slick.css' );
	 
      // If you need any javascript files on front end, here is how you can load them.
    }

    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(esc_html__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'kiwi'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new VCExtendAddonClassCategoryBlock();