<?php

// don't load directly
if (!defined('ABSPATH')) die('-1');


class VCExtendAddonClassSlider {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'integrateWithVC' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'eddslider', array( $this, 'renderMyeddslider' ) );

        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
    }
 
    public function integrateWithVC() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }
		
		$wpkses = array(
			'br' => array(),
			'em' => array(),
			'strong' => array(),
			'small' => array(),
			'b' => array(),
			'i' => array(),
			'u' => array(),
			'span' => array(),
		);
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
	
$theme = wp_get_theme();

if ('Theme Kiwi :: Marketplace' == $theme->name || 'Theme Kiwi :: Marketplace' == $theme->parent_theme) {	
	$layout_design_settings = array( 
		esc_html__( 'Select', 'kiwi' ) => '',
		esc_html__( 'Thumbnails only', 'kiwi' ) => 'edd_thumbnails',
		esc_html__( 'Grid style 1', 'kiwi' ) => 'grid_style_one',
		esc_html__( 'Grid style 2', 'kiwi' ) => 'grid_style_two',	
		esc_html__( 'Grid style 3', 'kiwi' ) => 'grid_style_three',
	);		
} else {	
	$layout_design_settings = array( 
		esc_html__( 'Select', 'kiwi' ) => '',
		esc_html__( 'Thumbnails only', 'kiwi' ) => 'edd_thumbnails',
		esc_html__( 'Grid style 1', 'kiwi' ) => 'grid_style_one',
		esc_html__( 'Grid style 2', 'kiwi' ) => 'grid_style_two',	
		esc_html__( 'Grid style 3', 'kiwi' ) => 'grid_style_three',
		$theme->name => 'custom-theme',	
	);	
}
	
$categories_array = array( esc_html__('All Categories', 'kiwi' ) => '' );
$category_list = get_terms( 'download_category', array( 'hide_empty' => false ) );

	if ( is_array( $category_list ) && ! empty( $category_list ) ) {
		foreach ( $category_list as $category_details ) {	
			$begin = __(' (ID: ', 'kiwi');
			$end = __(')', 'kiwi');
			$categories_array[ $category_details->name . $begin. $category_details->term_id . $end ] = $category_details->term_id;	
		}
	} 		 
        vc_map( array(
            "name" => esc_html__("Marketplace :: Slider", 'kiwi'),
            "description" => esc_html__("Create a slider", 'kiwi'),
            "base" => "eddslider",
            "class" => "",
            "controls" => "full",		
            "icon" => "icon-kiwi-slider",
			"category" => esc_html__('EDD', 'kiwi'),
          //  'admin_enqueue_css' => array(plugins_url('../css/kiwi-vc-addon.css', __FILE__)),
			"params" => array(
    
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Heading', 'kiwi' ),
		'param_name'       => 'kiwi_edd_slider_heading',
		'edit_field_class' => 'vc_col-sm-12 vc_column',		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Heading text', 'kiwi' ),
		'param_name' => 'heading_text',
		'value' => '', 
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Add title (e.g., Latest Additions)', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		
	),
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Total items', 'kiwi' ),
		'param_name' => 'total_items',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set max. number of items inside your carousel.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Slider Settings', 'kiwi' ),
		'param_name'       => 'kiwi_edd_products_heading',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Transition <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'setting_fade',
			'value'       => array(
				esc_html__( 'Select effect', 'kiwi' ) => '',
				esc_html__( 'Slide', 'kiwi' ) => 'false',
				esc_html__( 'Fade', 'kiwi' ) => 'true',				
				),			
			'description' => 'Select slide or fade effect.<br /><br />',	
			'edit_field_class' => 'vc_col-sm-4 vc_column',	
	),
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Items per view <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'items_per_view',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set number of items per view.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-4 vc_column',
	),
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Items per scroll <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'items_per_scroll',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set number of items per scroll.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-4 vc_column',
	),
	
	
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Autoplay <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'slide_autoplay',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Enable', 'kiwi' ) => 'true',
				esc_html__( 'Disable', 'kiwi' ) => 'false',
				),			
			'description' => ' ',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	), 
	


	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Speed <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'autoplay_speed',
		'value' => '', 
		'description' => esc_html__('Set autoplay speed in milliseconds.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Infinite Loop <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'infinite_loop',
			'value'       => array(			
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Enable', 'kiwi' ) => 'true',
				esc_html__( 'Disable', 'kiwi' ) => 'false',
				),			
			'description' => ' ',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Slide speed <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'slide_speed',
		'value' => '', 
		'description' => esc_html__('Set slide animation speed in milliseconds.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	
	
	
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Adaptive Height <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'adaptive_height',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Enable', 'kiwi' ) => 'true',
				esc_html__( 'Disable', 'kiwi' ) => 'false',
				),			
			'description' => ' ',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('RTL Mode <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'item_rtl',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Enable', 'kiwi' ) => 'true',
				esc_html__( 'Disable', 'kiwi' ) => 'false',						
				),			
			'description' => ' ',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Spacing between slides', 'kiwi' ),
		'param_name' => 'slides_spacing',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Leave blank for no spacing (numeric only).', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Navigation', 'kiwi' ),
		'param_name'       => 'kiwi_edd_slider_nav',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Show nav arrows', 'kiwi' ),
			'param_name' => 'arrows',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Yes', 'kiwi' ) => 'true',
				esc_html__( 'No', 'kiwi' ) => 'false',					
				),			
			'description' => ' ',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Show nav dots', 'kiwi' ),
			'param_name' => 'dots',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Yes', 'kiwi' ) => 'true',
				esc_html__( 'No', 'kiwi' ) => 'false',					
				),			
			'description' => ' ',
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
			
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Layout', 'kiwi' ),
			'param_name' => 'slide_nav_layout',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Style one', 'kiwi' ) => 'style-one',
				esc_html__( 'Style two', 'kiwi' ) => 'style-two',				
				),			
			'description' => 'Layout options for navigation.',	
			'edit_field_class' => 'vc_col-sm-6 vc_column',	
	),
	
	
	// Design settings
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Design', 'kiwi' ),
			'param_name' => 'setting_design',
			'value' => $layout_design_settings,		
			'description' => '<br />',	
			'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
			'group' => esc_html__('Design Settings', 'kiwi' ),			
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Slider width', 'kiwi' ),
		'param_name' => 'slider_width',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('(optional) Control the width of the slider. e.g.: 80%', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Design Settings', 'kiwi' ),
	),
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Thumbnail Settings', 'kiwi' ),
		'param_name'       => 'kiwi_edd_thumb_settings',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'setting_design', 'value' => 'edd_thumbnails' ),		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Size of the thumbnails', 'kiwi' ),
		'param_name' => 'thumbnail_size',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set thumbnail width (e.g., 80). Numeric only.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'setting_design', 'value' => 'edd_thumbnails' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Size of the thumbnails', 'kiwi' ),
		'param_name' => 'thumbnail_size_height',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Set thumbnail height (e.g., 80). Numeric only.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'setting_design', 'value' => 'edd_thumbnails' ),
	),
	
	
	array(
			'type'             => 'kiwi_vc_param_heading',
			'title'            => esc_html__( 'Styling (thumbnails only)', 'kiwi' ),
			'param_name'       => 'kiwi_edd_slider_thumb_styling',
			'edit_field_class' => 'vc_col-sm-12 vc_column',
			'group' => esc_html__('Design Settings', 'kiwi' ),
			'dependency' => Array('element' => 'setting_design', 'value' => 'edd_thumbnails' ),
		),
		
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Extra styling?', 'kiwi' ),
		'param_name' => 'thumbnail_extra_styling',
		'description' => esc_html__('Enable extra styling.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'dependency' => Array('element' => 'setting_design', 'value' => 'edd_thumbnails' ),	
		),
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Border', 'kiwi' ),
		'param_name' => 'thumbnail_border',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Border e.g.: 1px solid #e8e8e8', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'thumbnail_extra_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Padding', 'kiwi' ),
		'param_name' => 'thumbnail_padding',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Padding e.g.: 5px 5px 5px 5px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'thumbnail_extra_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Background', 'kiwi' ),
		'param_name' => 'thumbnail_background',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Background color. E.g.: #ffffff', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'thumbnail_extra_styling', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Margin', 'kiwi' ),
		'param_name' => 'thumbnail_margin',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Margin. E.g.: 0px 1.4% 1.4% 0px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'thumbnail_extra_styling', 'value' => 'yes' ),
	),
	
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Excerpt Settings', 'kiwi' ),
		'param_name'       => 'kiwi_edd_slider_excerpt',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'setting_design', 'value' => 'grid_style_two' ),			
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt length', 'kiwi' ),
		'param_name' => 'grid_style_two_excerpt_length',
		'description' => 'E.g. 50',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),
		'value' => '', // default value	
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'setting_design', 'value' => 'grid_style_two' ),		
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt ending', 'kiwi' ),
		'param_name' => 'grid_style_two_excerpt_ending',
		'description' => 'E.g. ... [dots]',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),
		'value' => '', // default value		
		'edit_field_class' => 'vc_col-sm-6  vc_column',
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array('element' => 'setting_design', 'value' => 'grid_style_two' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Excerpt link text', 'kiwi' ),
		'param_name' => 'grid_style_two_excerpt_link',
		'description' => 'E.g. View full description »',
		'group' => esc_html__('Excerpt Settings', 'kiwi' ),		
		'value' => ' ', // default value	
		'group' => esc_html__('Design Settings', 'kiwi' ),
		//'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'setting_design', 'value' => 'grid_style_two' ),		
	),
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Truncate Title', 'kiwi' ),
		'param_name'       => 'kiwi_heading_slider_trunc',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),
		'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_two','grid_style_one','grid_style_three','custom-theme') ),			
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Truncate item title?', 'kiwi' ),
		'param_name' => 'grid_style_two_truncate_title',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),	
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_two','grid_style_one','grid_style_three','custom-theme') ),		
		),
		
		
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Length', 'kiwi' ),
			'param_name' => 'grid_truncate_lenght',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( '1 line', 'kiwi' ) => 'one-line',
				esc_html__( '2 lines', 'kiwi' ) => 'two-lines',
				esc_html__( '3 lines', 'kiwi' ) => 'three-lines',
				esc_html__( '4 lines', 'kiwi' ) => 'four-lines',				
				),			
			'description' => '<br />',	
			'edit_field_class' => 'vc_col-sm-6 vc_column',
			'group' => esc_html__('Design Settings', 'kiwi' ),	
			'dependency' => Array( 'element' => 'grid_style_two_truncate_title', 'value' => Array('yes') ),				
	),
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Center Mode', 'kiwi' ),
		'param_name'       => 'kiwi_edd_slider_centermode',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),				
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable center mode?', 'kiwi' ),
		'param_name' => 'mp_slider_centermode',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),	
		'edit_field_class' => 'vc_col-sm-6 vc_column-with-padding',
		'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_two','grid_style_one','grid_style_three') ),		
		),
		
		array(
			'type' => 'checkbox',
			'heading' => esc_html__('Enable opacity effect?', 'kiwi' ),
			'param_name' => 'mp_slider_centermode_opacity',
			'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),		
			'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
			'group' => esc_html__('Design Settings', 'kiwi' ),
			'dependency' => Array( 'element' => 'mp_slider_centermode', 'value' => 'yes' ),	
		),
	
		array(
			'type' => 'textfield',
			'heading' => esc_html__('Center mode padding', 'kiwi' ),
			'param_name' => 'mp_slider_centermode_padding',
			'value' => '', // default value
			//'param_holder_class' => 'vc_not-for-custom',
			'description' => esc_html__('(e.g., 60). Numeric only.', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
			'group' => esc_html__('Design Settings', 'kiwi' ),
			'dependency' => Array( 'element' => 'mp_slider_centermode', 'value' => 'yes' ),	
		),
	
	
	
	
	array(
			'type'             => 'kiwi_vc_param_heading',
			'title'            => esc_html__( 'Featured Image only', 'kiwi' ),
			'param_name'       => 'kiwi_slider_hide_cap',
			'edit_field_class' => 'vc_col-sm-12 vc_column',
			'group' => esc_html__('Design Settings', 'kiwi' ),	
			'dependency' => Array('element' => 'setting_design', 'value' => 'grid_style_one' ),	
		),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Hide caption?', 'kiwi' ),
		'param_name' => 'hide_caption',
		'description' => esc_html__('Hide title and author name, so that only featured images are displayed.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' 			=> 	esc_html__('Design Settings', 'kiwi' ),	
		'dependency' => Array('element' => 'setting_design', 'value' => 'grid_style_one' ),	
		),		
	
	
		
	/* array(
		'type' => 'checkbox',
		'heading' => esc_html__('Tooltip', 'kiwi' ),
		'param_name' => 'mp_tooltip_thumbnails',
		'description' => esc_html__('Enable Preview Tooltip.', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Design Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array('element' => 'setting_design', 'value' => 'edd_thumbnails' ),	
	), */	
	
	
	
	
	
	
	
	
		  
	// Data settings
	array(
			'type'             => 'kiwi_vc_param_heading',
			'title'            => esc_html__( 'WP Query', 'kiwi' ),
			'param_name'       => 'kiwi_edd_slider_query',
			'edit_field_class' => 'vc_col-sm-12 vc_column',
			'group' => esc_html__('Data Settings', 'kiwi' ),
		),
		
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Order by', 'kiwi' ),
		'param_name' => 'slider_orderby',
		'value' => array(
			esc_html__( 'Date', 'kiwi' ) => 'date',
			esc_html__( 'Order by post ID', 'kiwi' ) => 'ID',
			esc_html__( 'Author', 'kiwi' ) => 'author',
			esc_html__( 'Title', 'kiwi' ) => 'title',
			esc_html__( 'Last modified date', 'kiwi' ) => 'modified',
		//	esc_html__( 'Post/page parent ID', 'kiwi' ) => 'parent',
			esc_html__( 'Number of comments', 'kiwi' ) => 'comment_count',
		//	esc_html__( 'Menu order/Page Order', 'kiwi' ) => 'menu_order',
			esc_html__( 'Meta value', 'kiwi' ) => 'meta_value',
			esc_html__( 'Meta value number', 'kiwi' ) => 'meta_value_num',
		//  esc_html__('Matches same order you passed in via the 'include' parameter.', 'kiwi') => 'post__in'
			esc_html__( 'Random order', 'kiwi' ) => 'rand',
		),
		'description' => wp_kses(__('Select order type.', 'kiwi'), $wpkses),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6  vc_column',
		
	),
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Sorting', 'kiwi' ),
		'param_name' => 'slider_sorting',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'Descending', 'kiwi' ) => 'DESC',
			esc_html__( 'Ascending', 'kiwi' ) => 'ASC',
		),
		'description' => esc_html__('Select sorting order.', 'kiwi' ),	
		'edit_field_class' => 'vc_col-sm-6  vc_column',
				
	),
	 array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Meta key <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'slider_metakey',
		'description' => wp_kses(__('Input meta key for grid ordering. (e.g., <b>_edd_download_sales</b> for most sales)', 'kiwi'), $wpkses),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => '',		
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array( 'element' => 'slider_orderby', 'value' => Array('meta_value','meta_value_num') ),		
	), 
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Meta query value', 'kiwi' ),
		'param_name' => 'slider_query_value',
		'description' => esc_html__('Extra filter for meta_key.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => '',		
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array( 'element' => 'slider_orderby', 'value' => Array('meta_value','meta_value_num') ),
	),
	
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Compare', 'kiwi' ),
		'param_name' => 'slider_comparison',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'Equal', 'kiwi' ) => 'EQUAL',
			esc_html__( 'Does not equal', 'kiwi' ) => 'NOT_EQUAL',
			esc_html__( 'Greater than', 'kiwi' ) => 'GREATER_THAN',
			esc_html__( 'Greater than or equal to', 'kiwi' ) => 'GREATER_EQUAL',
			esc_html__( 'Less than', 'kiwi' ) => 'LESS_THAN',
			esc_html__( 'Less than or equal to', 'kiwi' ) => 'LESS_THAN_OR_EQUAL',			
			esc_html__( 'LIKE', 'kiwi' ) => 'LIKE',
			esc_html__( 'NOT LIKE', 'kiwi' ) => 'NOT_LIKE',
			esc_html__( 'IN', 'kiwi' ) => 'IN',
			esc_html__( 'NOT IN', 'kiwi' ) => 'NOT_IN',
			esc_html__( 'BETWEEN', 'kiwi' ) => 'BETWEEN',
			esc_html__( 'NOT BETWEEN', 'kiwi' ) => 'NOT_BETWEEN',
			esc_html__( 'EXISTS', 'kiwi' ) => 'EXISTS',
			esc_html__( 'NOT EXISTS', 'kiwi' ) => 'NOT_EXISTS',
		),
		'description' => esc_html__('Compare settings against specific meta values.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array( 'element' => 'slider_orderby', 'value' => Array('meta_value','meta_value_num') ),
				
	),
	
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Offset', 'kiwi' ),
		'param_name' => 'slider_offset',
		'description' => esc_html__('Number of grid elements to displace or pass over.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => 0, // default value	
		'edit_field_class' => 'vc_col-sm-6 vc_column',			
	),
	
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Category', 'kiwi' ),
		'param_name'       => 'kiwi_edd_slider_cat',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Data Settings', 'kiwi' ),
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => esc_html__('Select Category', 'kiwi' ),
			'param_name' => 'slider_category',
			'value' => $categories_array,			
			'description' => esc_html__('Select category.', 'kiwi' ),
			'group' => esc_html__('Data Settings', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Exclude categories', 'kiwi' ),
		'param_name' => 'slider_exclude',
		'description' => esc_html__('Exclude categories by adding category id\'s separated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		//'value' => 0, // default value
		'edit_field_class' => 'vc_col-sm-6 vc_column',		
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Include multiple categories?', 'kiwi' ),
		'param_name' => 'grid_multi_cats_query',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',		
		),
				
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Multiple categories', 'kiwi' ),
		'param_name' => 'grid_multi_cats_include',
		'description' => esc_html__('Include category ID\'s separated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',	
		'dependency' => array( 'element' => 'grid_multi_cats_query', 'value' => 'yes' ),
	), 
	
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Relation', 'kiwi' ),
		'param_name' => 'grid_multi_cats_relation',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'And', 'kiwi' ) => 'AND',
			esc_html__( 'Or', 'kiwi' ) => 'OR',			
		),
		'edit_field_class' => 'vc_col-sm-6 vc_column',	
		'dependency' => array( 'element' => 'grid_multi_cats_query', 'value' => 'yes' ),		
	),		  
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Tags', 'kiwi' ),
		'param_name'       => 'kiwi_edd_grid_tags',
		'edit_field_class' => 'vc_col-sm-12 vc_column',	
		'group' 		   => esc_html__('Data Settings', 'kiwi' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Include EDD tags to WP Query', 'kiwi' ),
		'param_name' => 'grid_tags_query',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',		
		),
		
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Include tags', 'kiwi' ),
		'param_name' => 'grid_tags_query_include',
		'description' => esc_html__('Include tags by adding tag id\'s separated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',	
		'dependency' => array( 'element' => 'grid_tags_query', 'value' => 'yes' ),
	), 
	
	array(
		'type' => 'dropdown',
		'heading' => esc_html__('Relation', 'kiwi' ),
		'param_name' => 'grid_tags_query_relation',
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'value' => array(
			esc_html__( 'And', 'kiwi' ) => 'AND',
			esc_html__( 'Or', 'kiwi' ) => 'OR',			
		),
		//'description' => esc_html__('Compare settings against specific meta values.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',	
		'dependency' => array( 'element' => 'grid_tags_query', 'value' => 'yes' ),		
	),		
	
	array(
		'type'             => 'kiwi_vc_param_divider',
		//'title'            => esc_html__( 'Portfolio', 'kiwi' ),
		'param_name'       => 'kiwi_divider_meta_author',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Data Settings', 'kiwi' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add author parameter', 'kiwi' ),
		'param_name' => 'grid_author_parameter',
		'description' => esc_html__(' ', 'kiwi' ),
		'value' => array( esc_html__('Yes, please.', 'kiwi' ) => 'yes' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column-with-padding',
		//'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_two','grid_style_one','grid_style_three') ),		
		),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Author ID', 'kiwi' ),
		'param_name' => 'grid_author_parameter_id',
		'description' => esc_html__('Enter single or multiple author ID\'s, seperated by a comma.', 'kiwi' ),
		'group' => esc_html__('Data Settings', 'kiwi' ),
		//'value' => 0, // default value
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'dependency' => Array( 'element' => 'grid_author_parameter', 'value' => Array('yes') ),		
	),
	
	
	
	// Responsive
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( '480px wide breakpoint', 'kiwi' ),
		'param_name'       => 'kiwi_slider_breakpoint_small',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Responsive', 'kiwi' ),	
	),
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Items per view <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'slide_breakpoint_small',
		'value' => '', 
		'description' => esc_html__('480px wide breakpoint.', 'kiwi' ),
		'group' => esc_html__('Responsive', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6',
	),
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Items per scroll <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'slide_scroll_small',
		'value' => '', 
		'description' => esc_html__('480px wide breakpoint.', 'kiwi' ),
		'group' => esc_html__('Responsive', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6',
	),
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Show nav arrows <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'slide_breakpoint_small_arrows',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Yes', 'kiwi' ) => 'true',
				esc_html__( 'No', 'kiwi' ) => 'false',					
				),			
			'description' => ' ',
			'group' => esc_html__('Responsive', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Show nav dots <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'slide_breakpoint_small_dots',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Yes', 'kiwi' ) => 'true',
				esc_html__( 'No', 'kiwi' ) => 'false',					
				),			
			'description' => ' ',
			'group' => esc_html__('Responsive', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( '768px wide breakpoint', 'kiwi' ),
		'param_name'       => 'kiwi_slider_breakpoint_medium',
		'group' => esc_html__('Responsive', 'kiwi' ),	
		'edit_field_class' => 'vc_col-sm-12 vc_column',
	),
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Items per view <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'slide_breakpoint_middle',
		'value' => '', 
		'description' => esc_html__('768px wide breakpoint.', 'kiwi' ),
		'group' => esc_html__('Responsive', 'kiwi' ),		
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
	),
	
	array(
		'type' => 'textfield',
		'heading' => wp_kses(__('Items per scroll <span>(*)</span>', 'kiwi'), $wpkses),
		'param_name' => 'slide_scroll_middle',
		'value' => '', 
		'description' => esc_html__('768px wide breakpoint.', 'kiwi' ),
		'group' => esc_html__('Responsive', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Show nav arrows <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'slide_breakpoint_middle_arrows',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Yes', 'kiwi' ) => 'true',
				esc_html__( 'No', 'kiwi' ) => 'false',					
				),			
			'description' => ' ',
			'group' => esc_html__('Responsive', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column ',
	),
	
	
	array(
			'type' => 'dropdown',
			'heading' => wp_kses(__('Show nav dots <span>(*)</span>', 'kiwi'), $wpkses),
			'param_name' => 'slide_breakpoint_middle_dots',
			'value'       => array(
				esc_html__( 'Select', 'kiwi' ) => '',
				esc_html__( 'Yes', 'kiwi' ) => 'true',
				esc_html__( 'No', 'kiwi' ) => 'false',					
				),			
			'description' => ' ',
			'group' => esc_html__('Responsive', 'kiwi' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
	),
	
	
	// Styling
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Grid Styling', 'kiwi' ),
		'param_name'       => 'kiwi_edd_grid_styling_settings',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' 			=> esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_one','grid_style_two','grid_style_three') ),	
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable extra styling?', 'kiwi' ),
		'param_name' => 'grid_extra_styling_box',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
		'dependency' => Array( 'element' => 'setting_design', 'value' => Array('grid_style_one','grid_style_two','grid_style_three') ),	
	),
	
		array(
		'type' => 'textfield',
		'heading' => esc_html__('Spacing', 'kiwi' ),
		'param_name' => 'grid_spacing_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Spacing inside each grid. (e.g. 5px 10px 5px 10px)', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Spacing', 'kiwi' ),
		'param_name' => 'grid_spacing_box_extra',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Additional spacing around text.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Border color', 'kiwi' ),
		'param_name' => 'grid_border_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Background color', 'kiwi' ),
		'param_name' => 'grid_background_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Title color', 'kiwi' ),
		'param_name' => 'grid_title_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Title hover color', 'kiwi' ),
		'param_name' => 'grid_title_hover_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),	
	
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Excerpt color', 'kiwi' ),
		'param_name' => 'grid_excerpt_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Price color', 'kiwi' ),
		'param_name' => 'grid_price_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Category color', 'kiwi' ),
		'param_name' => 'grid_category_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Category hover color', 'kiwi' ),
		'param_name' => 'grid_category_hover_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Coming Soon color', 'kiwi' ),
		'param_name' => 'grid_coming_soon_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Only works if Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Coming Soon bg color', 'kiwi' ),
		'param_name' => 'grid_coming_soon_background_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('Only works if Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
		
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Author text color', 'kiwi' ),
		'param_name' => 'grid_author_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('Text color when Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Author hover color', 'kiwi' ),
		'param_name' => 'grid_author_hover_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('Text color when Coming Soon plugin is activated.', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),	
	
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Add box shadow?', 'kiwi' ),
		'param_name' => 'grid_shadow_box',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'grid_extra_styling_box', 'value' => 'yes' ),
	),
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Heading Styling', 'kiwi' ),
		'param_name'       => 'kiwi_edd_grid_styling_heading',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Styling settings', 'kiwi' ),
	),
	
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable extra heading styling?', 'kiwi' ),
		'param_name' => 'slider_extra_styling_heading_box',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
	),
	
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Text color', 'kiwi' ),
		'param_name' => 'slider_heading_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-4 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'slider_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Background color', 'kiwi' ),
		'param_name' => 'slider_heading_bgcolor_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-4 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'slider_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__('Border color', 'kiwi' ),
		'param_name' => 'slider_heading_border_color_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		//'description' => esc_html__('border color', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-4 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'slider_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Heading padding', 'kiwi' ),
		'param_name' => 'slider_heading_padding_box',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('E.g. 5px 10px 5px 10px', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'dependency' => Array('element' => 'slider_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable full width?', 'kiwi' ),
		'param_name' => 'slider_heading_bg_fullwidth',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'slider_extra_styling_heading_box', 'value' => 'yes' ),
	),
	
	
	
	array(
		'type'             => 'kiwi_vc_param_heading',
		'title'            => esc_html__( 'Navigation Styling', 'kiwi' ),
		'param_name'       => 'kiwi_edd_products_styling',
		'edit_field_class' => 'vc_col-sm-12 vc_column',
		'group' => esc_html__('Styling settings', 'kiwi' ),
	),
	
	array(
		'type' => 'checkbox',
		'heading' => esc_html__('Enable extra navigation arrow styling?', 'kiwi' ),
		'param_name' => 'slider_extra_styling_navigation',
		'value' => array( esc_html__('Yes', 'kiwi' ) => 'yes' ),
		//'description' => esc_html__('Append filter to grid.', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-12 vc_column vc_column-with-padding',
	),
	
	
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Border', 'kiwi' ),
		'param_name' => 'slider_extra_styling_navigation_border',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('E.g.: 1px solid #e8e8e8', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'slider_extra_styling_navigation', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Border radius', 'kiwi' ),
		'param_name' => 'slider_extra_styling_navigation_radius',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('E.g.: 5px', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'slider_extra_styling_navigation', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Padding left arrow', 'kiwi' ),
		'param_name' => 'slider_extra_styling_navigation_leftarrow',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('E.g.: 5px 5px 5px 5px', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'slider_extra_styling_navigation', 'value' => 'yes' ),
	),
	
	array(
		'type' => 'textfield',
		'heading' => esc_html__('Padding right arrow', 'kiwi' ),
		'param_name' => 'slider_extra_styling_navigation_rightarrow',
		'value' => '', // default value
		//'param_holder_class' => 'vc_not-for-custom',
		'description' => esc_html__('E.g.: 5px 5px 5px 5px', 'kiwi' ),
		'group' => esc_html__('Styling settings', 'kiwi' ),
		'edit_field_class' => 'vc_col-sm-6 vc_column vc_column-with-padding',
		'dependency' => Array('element' => 'slider_extra_styling_navigation', 'value' => 'yes' ),
	),
	
	
	
	
	
			  
            )
        ) );
    }
    
    /*
    Shortcode logic how it should be rendered
    */
    public function renderMyeddslider( $atts, $content = null ) {
      extract( shortcode_atts( array(	  
		'output' => '',
        'heading_text' => '',
		'total_items' => '',
		'items_per_view' => '',
		'items_per_scroll' => '',
		'slide_autoplay' => '',
		'autoplay_speed' => '',
		'slide_speed' => '',
		'infinite_loop' => '',
		'adaptive_height' => '',
		'item_rtl' => '',
		'arrows' => '',
		'dots' => '',
		'slider_category' => '',
		'slider_orderby' => '',
		'slider_sorting' => '',
		'slider_metakey' => '',
		'slider_offset' => '',
		'slide_breakpoint_small' => '',
		'slide_breakpoint_small_arrows' => '',
		'slide_breakpoint_small_dots' => '',
		'slide_breakpoint_middle' => '',
		'slide_breakpoint_middle_arrows' => '',
		'slide_breakpoint_middle_dots' => '',
		'slide_scroll_small' => '',
		'slide_scroll_middle' => '',		
		'slides_spacing' => '',
		'slide_nav_layout' => '',
		'setting_fade' => '',
		'setting_design' => '',		
		'thumbnail_size' => '',
		'thumbnail_size_height' => '',
		'slider_width' => '',
		'hide_caption' => '',
		'slider_exclude' => '',
		'slider_query_value' => '',
		'slider_comparison' => '', 
		'grid_style_two_excerpt_length' => '', 
		'grid_style_two_excerpt_ending' => '', 
		'grid_style_two_excerpt_link' => '', 
		'grid_style_two_truncate_title' => '',		
		'slider_extra_styling_heading_box' => '',
		'slider_heading_color_box' => '',
		'slider_heading_bgcolor_box' => '',
		'slider_heading_border_color_box' => '',
		'slider_heading_padding_box' => '',
		'slider_heading_bg_fullwidth' => '',		
		'slider_extra_styling_navigation' => '',
		'slider_extra_styling_navigation_leftarrow' => '',
		'slider_extra_styling_navigation_rightarrow' => '',
		'slider_extra_styling_navigation_radius' => '',
		'slider_extra_styling_navigation_border' => '',		
		'thumbnail_padding' => '',
		'thumbnail_border' => '',		
		'thumbnail_extra_styling' => '',
		'thumbnail_background' => '',
		'thumbnail_margin' => '',		
		'grid_spacing_box' => '',
		'grid_border_box' => '',
		'grid_background_box' => '',
		'grid_shadow_box' => '',
		'grid_spacing_box_extra' => '',
		'grid_extra_styling_box' => '',
		'grid_title_color_box' => '',
		'grid_title_hover_color_box' => '',
		'grid_excerpt_color_box' => '',
		'grid_category_color_box' => '',
		'grid_category_hover_color_box' => '',
		'grid_price_box' => '',
		'grid_coming_soon_box' => '',
		'grid_coming_soon_background_box' => '',
		'grid_author_box' => '',
		'grid_author_hover_box' => '',	
		'grid_author_parameter' => '',	
		'grid_author_parameter_id' => '',
		'grid_truncate_lenght' => '',			
		'truncate_value' => '',		
		'mp_content_audio' => '',
		'mp_content' => '',
		'mp_slider_centermode' => '',
		'mp_slider_centermode_padding' => '',
		/* 'mp_tooltip_thumbnails' => '', */
		'mp_slider_centermode_opacity' => '',
		'kiwi_edd_grid_tags' => '',
		'grid_tags_query_include' => '',
		'grid_tags_query' => '',
		'grid_tags_query_relation' => '',
		'layout_design_settings' => '',
		'mp_edd_theme_custom_theme' => '',
		'grid_multi_cats_query' => '',
		'grid_multi_cats_include' => '',
		'grid_multi_cats_relation' => '', 
      ), $atts ) );
     $content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
     
	 global $kiwi_theme_option;
	
		$current_page = get_query_var('page');
		$per_page = get_option('posts_per_page');
		$offset = $current_page > 0 ? $per_page * ($current_page-1) : 0;
		
		$args = array(
			'post_type' 	 => 'download',
			'posts_per_page' => $total_items,
			'post_status'    => 'publish',
			'order'       	 => $slider_sorting,
			'orderby'        => $slider_orderby,			
			'offset' 		 => $slider_offset,
		);	
		
		
		
		if ( ! empty( $slider_metakey ) ){
			$args['meta_key'] = $slider_metakey;
		}
				
		
		 // extra author parameter
		if( isset( $grid_author_parameter_id ) && !empty ($grid_author_parameter_id) && $grid_author_parameter = 'yes'  ) {
			$args['author'] = $grid_author_parameter_id;
		}
		
		if( $slider_comparison == 'BETWEEN' || $slider_comparison == 'NOT_BETWEEN' || $slider_comparison == 'NOT_IN' || $slider_comparison == 'IN') {
			$slider_value = explode(',', $slider_query_value);
		} else {			
			$slider_value = $slider_query_value;
		} 
	
		
		// ** ** //
		 if( $slider_query_value !== '') {
		
			 if( $slider_comparison == 'EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => '=',
						'value' => $slider_value,
				);
			 } elseif( $slider_comparison == 'NOT_EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => '!=',
						'value' => $slider_value,
				);
			 } elseif( $slider_comparison == 'GREATER_THAN' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => '>',
						'value' => $slider_value,
				);
			 } elseif($slider_comparison == 'GREATER_EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => '>=',
						'value' => $slider_value,
				);
			 } elseif( $slider_comparison == 'LESS_THAN' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => '<',
						'value' => $slider_value,
				);
			 } elseif($slider_comparison == 'LESS_THAN_OR_EQUAL' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => '<=',
						'value' => $slider_value,
				);
			 }elseif($slider_comparison == 'NOT_LIKE' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'NOT LIKE',
						'value' => $slider_value,
				);
			 }elseif($slider_comparison == 'NOT_IN' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'NOT IN',
						'value' => $slider_value,
				);
			 } elseif($slider_comparison == 'NOT_BETWEEN' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'NOT BETWEEN',
						'value' => $slider_value,
				);
			 }  elseif($slider_comparison == 'NOT_EXISTS' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'NOT EXISTS',
						'value' => $slider_value,
				);
			 } elseif($slider_comparison == 'LIKE' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'LIKE',
						'value' => $slider_value,
				);
			 } elseif($slider_comparison == 'IN' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'IN',
						'value' => $slider_value,
				);
			 }
			 elseif($slider_comparison == 'BETWEEN' ) { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'BETWEEN',
						'value' => $slider_value,
				);
			 }
			 else { 
				$args['meta_query'][] = array(
						'key'     => $slider_metakey,
						'compare' => 'EXISTS',
						'value' => $slider_value,
				);
			 } 
			 
			 
			 
		 }			 
		 // ** ** //
		
		// if a category is selected
		    if( $slider_category != '' && $grid_multi_cats_query == '' ) {
			$args['tax_query'][] = array(
				'taxonomy'      	 => 'download_category',
				'field'         	 => 'term_id',
				'terms'          	 => $slider_category
				
			);
		  } 

		// include multi categories
		if( $grid_multi_cats_query == 'yes' && $grid_multi_cats_include != '' ) {
			$args['tax_query']['relation'] = $grid_multi_cats_relation;
			$args['tax_query'][] = array(
				'taxonomy'      	 => 'download_category',
				'field'         	 => 'term_id',
				'terms'          	 => explode(',', $grid_multi_cats_include),
				'operator' 			 => 'IN',
				
			);
		  } 	
		  
		 // exclude items
		if( $slider_exclude != '' && $slider_category == '' ) {
			$args['tax_query'][] = array(
				'taxonomy'      	 => 'download_category',
				'field'         	 => 'term_id',
				'terms'          	 => explode(',', $slider_exclude),
				'operator' 			 => 'NOT IN'
				
			);
		  } 
		  
		 // include tags
		if( $grid_tags_query == 'yes' && $grid_tags_query_include != '' ) {
			$args['tax_query']['relation'] = $grid_tags_query_relation;
			$args['tax_query'][] = array(
				'taxonomy'      	 => 'download_tag',
				'field'         	 => 'term_id',
				'terms'          	 => explode(',', $grid_tags_query_include),
				'operator' 			 => 'IN',
				
			);
		  }	 
		  
		$grid_mp_items = new WP_Query($args); 	
		
		$source = plugin_dir_path( dirname( __FILE__ ) ) . 'images/img-empty-featuredimage.jpg';
						
		$slide = 'li';
		
		$uniqid = uniqid('kiwi-slide-');

		$uniqid_nav_prev = uniqid('nav-arrow-prev-');	
		$uniqid_nav_next = uniqid('nav-arrow-next-');

		if( isset( $thumbnail_border ) && !empty ($thumbnail_border)  ) {
			$value_thumb_border = ' .'.$uniqid.' .layout-sorting.edd_thumbnails li.slick-slide {border:'.$thumbnail_border.';} ';
		} else {
			$value_thumb_border = '';
		}

		if( isset( $thumbnail_padding ) && !empty ($thumbnail_padding)  ) {
			$value_thumb_padding = ' .'.$uniqid.' .layout-sorting.edd_thumbnails li.slick-slide {padding:'.$thumbnail_padding.';} ';
		} else {
			$value_thumb_padding = '';
		}

		if( isset( $thumbnail_background ) && !empty ($thumbnail_background)  ) {
			$value_thumb_bg = ' .'.$uniqid.' .layout-sorting.edd_thumbnails li.slick-slide {background:'.$thumbnail_background.';} ';
		} else {
			$value_thumb_bg = '';
		}
		if( isset( $thumbnail_margin ) && !empty ($thumbnail_margin)  ) {
			$value_thumb_mar = ' .'.$uniqid.' .layout-sorting.edd_thumbnails li.slick-slide {margin:'.$thumbnail_margin.';} ';
		} else {
			$value_thumb_mar = '';
		}
				
		if( isset( $grid_background_box ) && !empty ($grid_background_box)  ) {
			$value_bg = ' .'.$uniqid.' li, .'.$uniqid.' .iso-desc { background:'.$grid_background_box.'!important;} ';
		} else {
			$value_bg = '';
		}
		
		if( isset( $grid_spacing_box ) && !empty ($grid_spacing_box)  ){
			$value_bgpd = ' .'.$uniqid.' li {  padding:'.$grid_spacing_box.'; }';
		} else {
			$value_bgpd = '';
		}
		
		if( isset( $grid_border_box ) && !empty ($grid_border_box) ){
			$value_bgbr = ' .'.$uniqid.' li { border:1px solid '.$grid_border_box.' } ';
		} else {
			$value_bgbr = '';
		}
		
				
		if( isset( $grid_spacing_box_extra ) && !empty ($grid_spacing_box_extra)  ) {
			$value_sp = ' .'.$uniqid.' .iso-desc {padding:'.$grid_spacing_box_extra.';} ';
		} else {
			$value_sp = '';
		}
		
		if( isset( $grid_title_color_box ) && !empty ($grid_title_color_box)  ) {
			$value_cl = ' .'.$uniqid.' .iso-desc .truncate h4 a, #'.$uniqid.' .iso-desc h4 a {color:'.$grid_title_color_box.'} ';
		} else {
			$value_cl = '';
		}
		
		if( isset( $grid_title_hover_color_box ) && !empty ($grid_title_hover_color_box)  ) {
			$value_clh = ' .'.$uniqid.' .iso-desc .truncate h4 a:hover {color:'.$grid_title_hover_color_box.'!important} ';
		} else {
			$value_clh = '';
		}			
		
		if( isset( $grid_excerpt_color_box ) && !empty ($grid_excerpt_color_box)  ) {
			$value_ex = ' .'.$uniqid.' .excerpt {color:'.$grid_excerpt_color_box.'} ';
		} else {
			$value_ex = '';
		}
		
		if( isset( $grid_category_color_box ) && !empty ($grid_category_color_box)  ) {
			$value_ct = ' .'.$uniqid.' .edd_catlist a {color:'.$grid_category_color_box.'} ';
		} else {
			$value_ct = '';
		}
		
		if( isset( $grid_category_hover_color_box ) && !empty ($grid_category_hover_color_box)  ) {
			$value_cth = ' .'.$uniqid.' .edd_catlist a:hover {color:'.$grid_category_hover_color_box.'} ';
		} else {
			$value_cth = '';
		}
		
		if( isset( $grid_price_box ) && !empty ($grid_price_box)  ) {
			$value_pr = ' .'.$uniqid.' .item-price {color:'.$grid_price_box.'} ';
		} else {
			$value_pr = '';
		}
		
		if( isset( $grid_coming_soon_box ) && !empty ($grid_coming_soon_box)  ) {
			$value_cm = ' .'.$uniqid.' .item-price.soon{color:'.$grid_coming_soon_box.'!important; } ';
		} else {
			$value_cm = '';
		}
		
		if ( !empty ($grid_coming_soon_background_box) ){
			$value_cmbg = ' .'.$uniqid.' .item-price.soon{background:'.$grid_coming_soon_background_box.'!important} ';
		} else {
			$value_cmbg = '';
		}
		
		
		
		if( isset( $grid_author_box ) && !empty ($grid_author_box)  ) {
			$value_at = ' .'.$uniqid.' .author a {color:'.$grid_author_box.'!important} ';
		} else {
			$value_at = '';
		}
		
		if( isset( $grid_author_hover_box ) && !empty ($grid_author_hover_box)  ) {
			$value_ath = ' .'.$uniqid.' .author a:hover {color:'.$grid_author_hover_box.'!important} ';
		} else {
			$value_ath = '';
		}
		
		if( $grid_shadow_box != '' ) {			
			$value_sha = ' .'.$uniqid.' li{-webkit-box-shadow: 0px 2px 5px -1px rgba(218, 218, 218, 1); -moz-box-shadow: 0px 2px 5px -1px rgba(218, 218, 218, 1); box-shadow: 0px 2px 5px -1px rgba(218, 218, 218, 1);} ';
		} else {
			$value_sha = '';
		}
		
					
$css_style = '<style>
#'.$uniqid.' .slick-slide {margin:0 '.$slides_spacing.'px!important;}
#'.$uniqid.' .slick-list {margin:0 -'.$slides_spacing.'px!important;}					
.slider-view #'.$uniqid.' .iso-desc {padding:0 0px 15px 0;}
.mp-kiwi-slider #'.$uniqid.' .iso-desc.div-flex {padding:0!important;}
.mp-kiwi-slider .layout-sorting.grid_style_two .iso-desc {padding:0!important;}	
.slider-view #'.$uniqid.' {width:'.$slider_width.'!important;} 					
'.$value_thumb_border.'
'.$value_thumb_padding.'
'.$value_thumb_bg.'
'.$value_thumb_mar.'
'.$value_cmbg.'
'.$value_bg.' 
'.$value_bgpd.'
'.$value_bgbr.' 
'.$value_sp.'   
'.$value_cl.'   
'.$value_clh.'   
'.$value_ex.'
'.$value_ct.'   
'.$value_cth.'   
'.$value_pr.'   
'.$value_cm.'   
'.$value_at.'
'.$value_ath.'  
'.$value_sha.'
</style>';
					
				
		
		if( isset( $slider_heading_color_box ) && !empty ($slider_heading_color_box)  ) {
			$value_grid_hdc = ' .'.$uniqid.' .edd_widget_title_vc h3 {color:'.$slider_heading_color_box.';} ';
		} else {
			$value_grid_hdc = '';
		}
		
		if( isset( $slider_heading_bgcolor_box ) && !empty ($slider_heading_bgcolor_box)  ) {
			$value_grid_hdc_bg = ' .'.$uniqid.' .edd_widget_title_vc h3 { background:'.$slider_heading_bgcolor_box.'} ';
		} else {
			$value_grid_hdc_bg = '';
		}
		
		if( isset( $slider_heading_border_color_box ) && !empty ($slider_heading_border_color_box)  ) {
			$value_grid_hdbc = ' .'.$uniqid.' .edd_widget_title_vc {background:'.$slider_heading_border_color_box.'} ';
		} else {
			$value_grid_hdbc = '';
		} 
		
		if( isset( $slider_heading_padding_box ) && !empty ($slider_heading_padding_box)  ) {
			$value_grid_hdpadding = ' .'.$uniqid.' .edd_widget_title_vc h3 {padding:'.$slider_heading_padding_box.'; height:auto;line-height:normal;} 
								 .'.$uniqid.' .edd_widget_title_vc {height:auto!important} 
								 .'.$uniqid.' .edd_widget_title_vc .style-one span {line-height:normal}
								 
								 ';
		} else {
			$value_grid_hdpadding = '';
		} 
		
		if( isset( $slider_heading_bg_fullwidth ) && !empty ($slider_heading_bg_fullwidth)  ) {
			$value_grid_hd_fullwidth = ' .'.$uniqid.' .edd_widget_title_vc h3 {display:inline-block; width:100%} ';
		} else {
			$value_grid_hd_fullwidth = '';
		}
		
		if( isset( $slider_extra_styling_navigation_border ) && !empty ($slider_extra_styling_navigation_border)  ) {
			$value_grid_nav_border = ' .'.$uniqid.' .edd_widget_title_vc .style-one span {border:'.$slider_extra_styling_navigation_border.'!important;}.mp-vc-kiwi-slider.slider-view .style-one {margin-top:0!important;}';
		} else {
			$value_grid_nav_border = '';
		}
		
		if( isset( $slider_extra_styling_navigation_radius ) && !empty ($slider_extra_styling_navigation_radius)  ) {
			$value_grid_nav_radius = ' .'.$uniqid.' .edd_widget_title_vc .style-one span {-webkit-border-radius:'.$slider_extra_styling_navigation_radius.';-moz-border-radius:'.$slider_extra_styling_navigation_radius.';border-radius:'.$slider_extra_styling_navigation_radius.';} ';
		} else {
			$value_grid_nav_radius = '';
		}
		
		if( isset( $slider_extra_styling_navigation_leftarrow ) && !empty ($slider_extra_styling_navigation_leftarrow)  ) {
			$value_grid_nav_leftarrow = ' .'.$uniqid.' .edd_widget_title_vc .style-one span:first-child { padding:'.$slider_extra_styling_navigation_leftarrow.';} ';
		} else {
			$value_grid_nav_leftarrow = '';
		}
		
		
		if( isset( $slider_extra_styling_navigation_rightarrow ) && !empty ($slider_extra_styling_navigation_rightarrow)  ) {
			$value_grid_nav_rightarrow = ' .'.$uniqid.' .edd_widget_title_vc .style-one span:last-child {margin-left: -1px;padding:'.$slider_extra_styling_navigation_rightarrow.';} ';
		} else {
			$value_grid_nav_rightarrow = '';
		}
		
		$css_style_custom_slide = '<style>
		'.$value_grid_hdc.'
		'.$value_grid_hdc_bg.'		
		'.$value_grid_hdbc.'		
		'.$value_grid_hdpadding.'		
		'.$value_grid_hd_fullwidth.'
		'.$value_grid_nav_border.'
		'.$value_grid_nav_radius.'
		'.$value_grid_nav_leftarrow.'
		'.$value_grid_nav_rightarrow.'		
		</style>';
		
		
		if( $slider_extra_styling_heading_box != '' || $slider_extra_styling_navigation != '' ) {			
			$output .= $css_style_custom_slide;
		}			
					

		$css_style_extra = '<style>	
					 .slider-view #'.$uniqid.' {width:'.$slider_width.'!important;} 
					</style>';
					
					
$css_style_responsive = '<style>	
@media (max-width:480px){ 
	.slider-view #'.$uniqid.' [class^="nav-arrow-prev"] {display:none!important} 
	.slider-view #'.$uniqid.' [class^="nav-arrow-next"] {display:none!important}						
	.slider-view .style-one .'.$uniqid_nav_prev.' {display:none!important}
	.slider-view .style-one .'.$uniqid_nav_next.' {display:none!important}
}
@media (min-width:481px) and (max-width:768px){ 
	.slider-view #'.$uniqid.' [class^="nav-arrow-prev"] {display:none!important} 
	.slider-view #'.$uniqid.' [class^="nav-arrow-next"] {display:none!important}						
	.slider-view .style-one .'.$uniqid_nav_prev.' {display:none!important}
	.slider-view .style-one .'.$uniqid_nav_next.' {display:none!important}
}
</style>';
			



			
		if( isset( $mp_slider_centermode_padding ) && !empty ($mp_slider_centermode_padding) && $mp_slider_centermode = 'yes'  ) {
			$mp_slider_centermode_active = "centerPadding:'{$mp_slider_centermode_padding}px'";
			$centermode_padding_class = ' yespadding';
		} else {
			$mp_slider_centermode_active = 'centerPadding:0';
			$centermode_padding_class = ' nopadding';
		}
		
		$theme = wp_get_theme();
			
			// EDD THEME :: Checkout
			if ('Checkout' == $theme->name || 'Checkout' == $theme->parent_theme) {				
				$theme_class = ' portfolio-wrapper download-wrapper';
				$edd_custom = ' mp-custom-theme';
			} elseif ('Marketify' == $theme->name || 'Marketify' == $theme->parent_theme) {				
				$theme_class = ' content-grid-download';	
				$edd_custom = ' mp-custom-theme';	
			} elseif ('SQUARECODE-WP' == $theme->name || 'SQUARECODE-WP' == $theme->parent_theme) {				
				$theme_class = '';	
				$edd_custom = ' mp-custom-theme';	
			} else {
				$theme_class = '';	
				$edd_custom = ' mp-custom-theme';	
			}
			
		if( $setting_design == 'edd_thumbnails' ) {
			$output_divclass = ' design-thumbnails';
		} elseif( $setting_design == 'grid_style_one' ) {
			$output_divclass = ' design-grid_style_one';
		} elseif( $setting_design == 'grid_style_two' ) {
			$output_divclass = ' design-grid_style_two';
		} elseif( $setting_design == 'grid_style_three' ) {
			$output_divclass = ' design-grid_style_three';
		} else {
			$output_divclass = ' mp-custom-design';
		}	
			
					
		if( isset( $mp_slider_centermode ) && !empty ($mp_slider_centermode) && $mp_slider_centermode = 'yes'  ) {
			$center_mode_value = 'true';
		} else {
			$center_mode_value = 'false';
		}

		$value = $items_per_view;
		$even = array(0, 2, 4, 6, 8);
		if(in_array(substr($value, -1),$even)){
		  $perview_value = ' even';
		}else{
		  $perview_value = ' odd';
		}		
			 
		$script = "<script type='text/javascript'>
			jQuery( document ).ready( function($) {         
				$(document).ready(function() {	
				
					$('#$uniqid').slick({					  
					 slide: 'li',
					 slidesToShow: $items_per_view,
					 slidesToScroll: $items_per_scroll,
					  autoplay: $slide_autoplay,
					  autoplaySpeed: $autoplay_speed,	
					  speed: $slide_speed,					  
					  arrows: $arrows,
					  dots: $dots,
					  adaptiveHeight: $adaptive_height,
					  rtl: $item_rtl,
					  infinite: $infinite_loop,
					  lazyLoad: 'ondemand',					  
				      prevArrow: '.$uniqid_nav_prev', 
					  nextArrow: '.$uniqid_nav_next',
					  fade: $setting_fade,
						centerMode: $center_mode_value,
						$mp_slider_centermode_active,
					  responsive: [
						{
						  breakpoint: 768,
						  settings: {
							arrows: $slide_breakpoint_middle_arrows,
							dots: $slide_breakpoint_middle_dots,										
							slidesToShow: $slide_breakpoint_middle,
							slidesToScroll: $slide_scroll_middle,
							centerMode: false,
						  }
						},
						{
						  breakpoint: 480,
						  settings: {
							arrows: $slide_breakpoint_small_arrows,
							dots: $slide_breakpoint_small_dots,										
							slidesToShow: $slide_breakpoint_small,
							slidesToScroll: $slide_scroll_small,
							centerMode: false,
						  }
						}
					]
						
					});


				$('.prev-slide').on('click', function (e) {
					e.preventDefault();	
					$('.slides').slick('$uniqid_nav_prev');
				});
				
				$('.next-slide').on('click', function (e) {
					e.preventDefault();
					$('.slides').slick('$uniqid_nav_next');
				});

					
				});
			}
		 );
		</script>";

		
		//if( isset( $slides_spacing ) && !empty ($slides_spacing)  ) {	
		if( $grid_extra_styling_box == 'yes' || !empty ($slides_spacing) ) {		
			$output .= $css_style;
		}
		
		if( isset( $slider_width ) && !empty ($slider_width)  ) {	
			$output .= $css_style_extra;
		}
		
		
		if( $slide_breakpoint_middle_arrows == 'false' || $slide_breakpoint_small_arrows == 'false' ) {	
			$output .= $css_style_responsive;
		}
		
		
		$output .= $script;
		
		
		/* */
		if( $grid_truncate_lenght == 'one-line' ) {
			$truncate_value = ' one-line';
		} elseif( $grid_truncate_lenght == 'two-lines' ) {
			$truncate_value = ' two-lines';
		}elseif( $grid_truncate_lenght == 'three-lines' ) {
			$truncate_value = ' three-lines';
		}elseif( $grid_truncate_lenght == 'four-lines' ) {
			$truncate_value = ' four-lines';
		} else {
			$truncate_value = ' no';
		}		 
		/* */
		
		
		if( isset( $mp_slider_centermode ) && !empty ($mp_slider_centermode) && $mp_slider_centermode = 'yes'  ) {
			$center_mode_class = ' centermode';
		} else {
			$center_mode_class = '';
		}
		
		if( isset( $mp_slider_centermode_opacity ) && !empty ($mp_slider_centermode_opacity) && $mp_slider_centermode_opacity = 'yes'  ) {
			$cm_opacity_effect = ' opacity-effect';
		} else {
			$cm_opacity_effect = '';
		}
		
		
		if( $slide_nav_layout == 'style-one' && $arrows == 'true' ) {																																							
				$output .= '<div class="mp-vc-kiwi-slider slider-view style-one '. esc_attr( $uniqid ).''. esc_attr( $center_mode_class ).''. esc_attr( $cm_opacity_effect ).''. esc_attr( $perview_value ).''. esc_attr( $centermode_padding_class ).''. esc_attr( $theme_class ).'">';
		} elseif( $slide_nav_layout == 'style-two' && $arrows == 'true' )  {
				$output .= '<div class="mp-vc-kiwi-slider slider-view style-two '. esc_attr( $uniqid ) .''. esc_attr( $center_mode_class ).''. esc_attr( $cm_opacity_effect ).''. esc_attr( $perview_value ).''. esc_attr( $centermode_padding_class ).''. esc_attr( $theme_class ).'">';
		} else {
				$output .= '<div class="mp-vc-kiwi-slider slider-view '. esc_attr( $uniqid ).''. esc_attr( $center_mode_class ).''. esc_attr( $cm_opacity_effect ).''. esc_attr( $perview_value ).''. esc_attr( $centermode_padding_class ).''. esc_attr( $theme_class ).'">';
		}
		
			
		if( isset( $heading_text ) && !empty ($heading_text)  ) {	
			$output .= "<div class='edd_widget_title_vc'><h3>{$heading_text}</h3>";
				if( $slide_nav_layout == 'style-one' && $arrows == 'true' ) {
					$output .= '<span class="style-one">';
					
			if ( is_rtl() ) {
				$output .= '<span class="'. esc_attr( $uniqid_nav_next ).' slick-arrow style-one" style="display: block;"><i class="fa fa-angle-right"></i></span>';
				$output .= '<span class="'. esc_attr( $uniqid_nav_prev ).' slick-arrow style-one" style="display: block;"><i class="fa fa-angle-left"></i></span>';	
			} else {				
				$output .= '<span class="'. esc_attr( $uniqid_nav_prev ).' slick-arrow style-one" style="display: block;"><i class="fa fa-angle-left"></i></span>';
				$output .= '<span class="'. esc_attr( $uniqid_nav_next ).' slick-arrow style-one" style="display: block;"><i class="fa fa-angle-right"></i></span>';
			}		
					
					$output .= '</span>';
				}	
			$output .= '</div>';
		}	
						
			
			
			
			
			if( $item_rtl == 'true' ) { 
				$output .= '<div class="mp-vc-items mp-kiwi-slider'. esc_attr( $output_divclass ).''. esc_attr( $edd_custom ).'" dir="rtl">';
			} else {
				$output .= '<div class="mp-vc-items mp-kiwi-slider'. esc_attr( $output_divclass ).''. esc_attr( $edd_custom ).'">';
			}

			
		if( $setting_design == '' ) { 
			$output .= '<div><ul id="'. esc_attr( $uniqid ).'" class="layout-sorting '. esc_attr( $setting_design) .'">';
		} elseif( $setting_design == 'grid_style_one' || $setting_design == 'grid_style_two' || $setting_design == 'grid_style_three' ) { 
			$output .= '<div class="grid-view"><ul id="'. esc_attr( $uniqid ).'" class="layout-sorting '. esc_attr( $setting_design ).'">';
		} elseif( $setting_design == 'edd_thumbnails'  ) { 
			$output .= '<div class="edd_thumbnails"><ul id="'. esc_attr( $uniqid ).'" class="layout-sorting '. esc_attr( $setting_design) .'">';
		} else {
			$output .= '<div><ul id="'. esc_attr( $uniqid ).'" class="layout-sorting">';
		}		
			
			
		if( $slide_nav_layout == 'style-two' && $arrows == 'true' ) {	
			$output .= '<span class="style-two">';
			$output .= '<div class="'. esc_attr( $uniqid_nav_prev ).' slick-arrow" style="display: block;"><i class="fa fa-angle-left"></i></div>';
			$output .= '<div class="'. esc_attr( $uniqid_nav_next ).' slick-arrow" style="display: block;"><i class="fa fa-angle-right"></i></div>';
			$output .= '</span>';
		}
		
		$have_results = $grid_mp_items->have_posts();
		if ( !empty( $have_results) && $grid_mp_items->have_posts() ) : while ( $grid_mp_items->have_posts() ) : $grid_mp_items->the_post();
				
		$thumbnails = get_the_ID();
		
		//$griddesign_excerpt = get_the_content();
		$griddesign_excerpt = get_post_field('post_content', get_the_ID());
		$griddesign_excerpt = esc_attr( strip_tags( stripslashes( $griddesign_excerpt ) ) );
		$griddesign_excerpt = preg_replace( '~^(\s*(?:&nbsp;)?)*~i', '', $griddesign_excerpt );		
				
		$readmore = ''. esc_html( $grid_style_two_excerpt_ending ) .' <a href="' . get_the_permalink() . '">'. esc_html( $grid_style_two_excerpt_link ) .'</a>';
		$griddesign_excerpt = wp_trim_words( $griddesign_excerpt, $num_words = $grid_style_two_excerpt_length, $more = $readmore );
		
		$source = plugin_dir_path( dirname( __FILE__ ) ) . 'images/img-empty-featuredimage.jpg';
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) ) {	
				
				$coming_soon_cs_active = edd_coming_soon_is_active( get_the_ID() );	
				
				$coming_soon_custom_text = get_post_meta( get_the_ID(), 'edd_coming_soon_text', true );
				$coming_soon_custom_text = !empty ( $coming_soon_custom_text ) ? $coming_soon_custom_text : apply_filters( 'edd_cs_coming_soon_text', esc_html__('Coming Soon', 'edd-coming-soon' ) );
			}
			
		if ( class_exists( 'EDD_Front_End_Submissions' ) ) {	
			$constant = EDD_FES()->helper->get_option( 'fes-vendor-constant', '' );
			$constant = ( isset( $constant ) && $constant != '' ) ? $constant : esc_html__( 'vendor', 'kiwi' );
            $constant = apply_filters( 'fes_vendor_constant_singular_lowercase', $constant );
		}	
		
		global $post;
			
			$name 			= get_the_author_meta('display_name', $post->post_author);
			$vendor_name	= get_the_author_meta( 'user_login' );
			$avatar			= get_avatar( get_the_author_meta( 'ID' ), 25 );
			
			$edd_catlist 	= get_the_term_list( $post->ID, 'download_category', '', ', ', '' );
		
		
		if( $setting_design == 'grid_style_two' ) { 
		
		$output .= "<li>";
		
		$output .= '<div class="iso-thumbnail">';
		
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
	
		$output .= '<div class="imageoverlay"></div>';
		
				
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = apply_filters( 'mp_plugin_edd_purchase_icon', '<span class="cart">'.$link.'</span>' );
		}
		
			
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink().'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		$output .= '</div>';
		
		
		$output .= '<div class="iso-desc">';
		
		   
		
		if( isset( $grid_style_two_truncate_title ) && !empty ($grid_style_two_truncate_title) && $grid_style_two_truncate_title  == 'yes') {	
			$output .= '<div class="truncate'. esc_attr( $truncate_value ).'">';
		} else {
			$output .= '<div>';
		}
		
		$output .= '<h4><a href="'. get_permalink().'">'.get_the_title().'</a></h4>';		
		$output .= '</div>';
		
		$output .= '<div class="excerpt">'. $griddesign_excerpt .'</div>';
		
		
		
		
		$output .= '<div class="custom-columns">';
		$output .= '<div class="left-column edd_catlist">';
		
		if ( !empty( $edd_catlist ) ){		
		   $output .= $edd_catlist;		
		}
		$output .= '</div>';
		
		$output .= '<div class="right-column align-right">';
		
			if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && $coming_soon_cs_active ) {			
				
			$price = apply_filters( 'edd_coming_soon_display_text', '' . $coming_soon_custom_text . '' );
		
		$output .= sprintf( '<span class="item-price soon">%s</span>', $price );		
		
		} else {
			
			remove_filter( 'edd_coming_soon_display_text', 'edd_coming_soon_get_custom_status_text', 30, 2 );
			
			$price = get_post_meta( get_the_ID(), 'edd_price', true );
					
					if ( $price == 0 && $kiwi_theme_option['marketplace-free-enable'] == '1' && !edd_has_variable_prices( get_the_ID() ) ) {
						$output .= '<span class="price free">';
						$price = $kiwi_theme_option['marketplace-free-customtext'];
						$output .= '</span>';
					} elseif ( edd_has_variable_prices( get_the_ID() ) ) {
						 $price = edd_price_range( get_the_ID() );
					} else {
						$price = edd_price( get_the_ID(), false );
					}						 
		$output .= sprintf( '<span class="item-price">%s</span>', $price );	
			
			}
		
		
		$output .= '</div>';
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		
		$output .= '<div class="left-column mp_author">';
		
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline with-avatar"><span class="author vcard">'. $avatar .'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name) .'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline with-avatar"><span class="author vcard">'. $avatar .'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}	
			
			$output .= '</div>';
				
		
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}	
		
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		$output .= "</li>";
		
		} elseif( $setting_design == 'edd_thumbnails' ) { 
		
			/* if( $mp_tooltip_thumbnails == 'yes' && has_post_thumbnail(get_the_ID())) { 
				$force_tool = ' featured-yes';			
			} elseif( $mp_tooltip_thumbnails == 'yes' ) { 
				$force_tool = '';
			} else {
				$force_tool = '';
			} */
		
			//$output .= "<li class='{$container_audio}{$force_tool}'>";
			$output .= '<li class="'. esc_attr( mp_media_class() ).'">';
			
			//tooltip
			/* if( $mp_tooltip_thumbnails == 'yes' ) { 
				$tooltip_output = mp_tooltip_effect();		
				$output .= '<div class="mp-vc-tooltip" data-toggle="tooltip" data-container="body" data-placement="auto" title="'. esc_html( $tooltip_output ).'">';
			} */ 
			
			$mp_featured_value = get_post_meta( get_the_ID(), 'mp_featured_item', true);
			
			if ( $mp_featured_value && $mp_featured_value == 'Yes' ) {	
				$output .= '<div class="featured-item-ribbon"><span></span></div>';				
			}
							
			if ( has_post_thumbnail() ) {
				$output .= '<div class="thumbnails"><a href="' . get_the_permalink() . '">';
				
			// ****************
			if ( class_exists( 'EDD_Front_End_Submissions' ) ) { 
			$vendor_thumbnail = get_post_meta( get_the_ID(), 'upload_item_thumbnail', true );	
			}
				if ( class_exists( 'EDD_Front_End_Submissions' ) && !empty( $vendor_thumbnail ) ) { 
					foreach($vendor_thumbnail as $key=>$val){
						$url = wp_get_attachment_image_src( $val, 'full' ); 
						$output .= '<img src="'. esc_url( $url[0] ) .'" width="'.$thumbnail_size.'" height="'.$thumbnail_size_height.'">';
					}
				} else {
					$mp_cmb_embedded = get_post_meta( get_the_ID(), '_cmb2_edd_thumbnail', true );					
					if ( !empty($mp_cmb_embedded) ) {				
						$output .= '<img src="'. esc_url( $mp_cmb_embedded ).'" width="'.$thumbnail_size.'" height="'.$thumbnail_size_height.'">';	
					} else {				
						$output .= get_the_post_thumbnail( get_the_ID(), array($thumbnail_size, $thumbnail_size_height) );
					}	
					
				}	
			// ****************					
				
				$output .= "</a>";
			} else { 
				$output .= '<div class="vc-post-items"><a href="' . get_the_permalink() . '">';
				$output .= '<img src="'. esc_url( $source ).'" width="'.$thumbnail_size.'" height="'.$thumbnail_size_height.'">';
				$output .= "</a>";
			}	
			
				//tooltip
				/* if( $mp_tooltip_thumbnails == 'yes' ) { 
					$output .= '</div>';
				} */

				$output .= apply_filters('mp_vc_widget_audio_only', $mp_content_audio);
						
			$output .= "</li>";	
					
		} elseif( $setting_design == 'grid_style_three' ) { 
		
		$output .= "<li>";
		
			$output .= '<div class="iso-thumbnail">';
		
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = '<span class="cart">'. $link .'</span>';
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink().'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		$output .= '</div>';
		
		
		$output .= '<div class="iso-desc div-flex">';
		
		
		if( isset( $grid_style_two_truncate_title ) && !empty ($grid_style_two_truncate_title) && $grid_style_two_truncate_title  == 'yes') {
			$output .= '<div class="left-column align-left truncate'. esc_attr( $truncate_value ).'">';
		} else {
			$output .= '<div class="left-column align-left">';
		}
		
		$output .= '<h4><a href="'. get_permalink().'">'.get_the_title().'</a></h4>';		
		$output .= '</div>';
		
		
		$output .= '<div class="right-column align-right">';
		
			if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && $coming_soon_cs_active ) {			
				
			$price = apply_filters( 'edd_coming_soon_display_text', '' . $coming_soon_custom_text . '' );
		
		$output .= sprintf( '<span class="item-price soon">%s</span>', $price );
		
		} else {
			
			remove_filter( 'edd_coming_soon_display_text', 'edd_coming_soon_get_custom_status_text', 30, 2 );
			
			$price = get_post_meta( get_the_ID(), 'edd_price', true );
					
					if ( $price == 0 && $kiwi_theme_option['marketplace-free-enable'] == '1' && !edd_has_variable_prices( get_the_ID() ) ) {
						$output .= '<span class="price free">';
						$price = $kiwi_theme_option['marketplace-free-customtext'];
						$output .= '</span>';
					} elseif ( edd_has_variable_prices( get_the_ID() ) ) {
						 $price = edd_price_range( get_the_ID() );
					} else {
						$price = edd_price( get_the_ID(), false );
					}						 
		$output .= sprintf( '<span class="item-price">%s</span>', $price );	
			
			}
		
		
		$output .= '</div>';
		$output .= '<div class="clear"></div>';
		$output .= '</div>';
		
		$output .= '<div class="mp_author">';
		
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline"><span class="author vcard">'. esc_html( 'by ', 'kiwi').'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ).'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline"><span class="author vcard">'. esc_html( 'by ', 'kiwi').'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}	
			
		if ( class_exists( 'EDD_Reviews' ) ) {		
			$output .= '<div class="right-column reviews align-right reviews-stylethree">';			
			$output .= mp_extension_review_function_vc();			
			$output .= '</div>'; 
		}	
			
		$output .= '</div>';		
		
		$output .= '<div class="clear"></div>';
		$output .= "</li>";
		
		} elseif( $setting_design == 'custom-theme' ) {
			
			$theme = wp_get_theme();
			
			// EDD THEME :: Checkout
			if ('Checkout' == $theme->name || 'Checkout' == $theme->parent_theme) {	
			
				if( isset( $grid_style_two_truncate_title ) && !empty ($grid_style_two_truncate_title) && $grid_style_two_truncate_title  == 'yes') {
					$output .= '<li class="truncate '. esc_attr( $grid_truncate_lenght ) .'">';
				} else {
					$output .= '<li>';
				}					
				$output .= apply_filters('mp_custom_edd_theme_checkout', $mp_edd_theme_checkout);
				$output .= '</li>';		
				
			} elseif ('Marketify' == $theme->name || 'Marketify' == $theme->parent_theme) {				
				if( isset( $grid_style_two_truncate_title ) && !empty ($grid_style_two_truncate_title) && $grid_style_two_truncate_title  == 'yes') {
					$output .= '<li class="truncate '. esc_attr( $grid_truncate_lenght ) .'">';
				} else {
					$output .= '<li>';
				}					
					$output .= apply_filters('mp_custom_edd_theme_marketify', $mp_edd_theme_marketify);
				$output .= '</li>';				
			} elseif ('SQUARECODE-WP' == $theme->name || 'SQUARECODE-WP' == $theme->parent_theme) {				
				if( isset( $truncate_title ) && !empty ($truncate_title) && $truncate_title  == 'yes') {
					$output .= '<li class="truncate '. esc_attr( $grid_truncate_lenght ) .'">';
				} else {
					$output .= '<li>';
				}					
					$output .= apply_filters('mp_custom_edd_theme_squarecode', $mp_edd_theme_squarecode);
				$output .= '</li>';				
			} else {
				if( isset( $grid_style_two_truncate_title ) && !empty ($grid_style_two_truncate_title) && $grid_style_two_truncate_title  == 'yes') {
					$output .= '<li class="truncate '. esc_attr( $grid_truncate_lenght ) .'">';
				} else {
					$output .= '<li>';
				}
					$output .= apply_filters('mp_custom_edd_theme_custom_design', $mp_edd_theme_custom_theme);
				$output .= '</li>';	
			} 			
			
		} else {
		
		$output .= "<li>";
		$output .= '<div class="iso-thumbnail">';
		
		$output .= apply_filters('mp_vc_widget_block_featured_image', $mp_content);
		
		$output .= '<div class="imageoverlay"></div>';
		
		
		if ( is_plugin_active( 'edd-coming-soon/edd-coming-soon.php' ) && edd_coming_soon_is_active() ) {
			$variable_class = '<span class="cart mp-comingsoon-class"><i class="fa fa-clock-o"></i></span>';			
		} else {
			$link = edd_get_purchase_link( array( 'textafter' => '<i class="fa fa-sign-out"></i>','text' => '<i class="fa fa-cart-arrow-down"></i>','price' => '0','download_id' => get_the_ID() ) );
			$variable_class = apply_filters( 'mp_plugin_edd_purchase_icon', '<span class="cart">'.$link.'</span>' );
		}
		
		
		$output .= '<div class="mp-button styleblock"><span class="viewmore"><a href="'. get_permalink().'"><i class="fa fa-eye"></i></a></span>';
		$output .= $variable_class;
		$output .= '</div>';
		
		
		
		$output .= '</div>';
		
		
		if( isset( $hide_caption ) && !empty ($hide_caption) && $hide_caption  == 'yes') {
				$output .= '';
		} else {	
		$output .= '<div class="iso-desc">';
		$output .= '<div class="truncate'. esc_attr( $truncate_value ).'">';
		$output .= '<h4><a href="'. get_permalink().'">'.get_the_title().'</a></h4>';
		$output .= '</div>';		
		
		$output .= '<div class="left-column mp_author">';
		
		global $post;
			
			$name 			= get_the_author_meta('display_name', $post->post_author);
			$vendor_name	= get_the_author_meta( 'user_login' );
			$avatar			= get_avatar( get_the_author_meta( 'ID' ), 25 );
			
			if ( class_exists( 'EDD_Front_End_Submissions' ) && !is_page_template( 'page-vendor.php' ) ) { 
					$output .= '<span class="byline with-avatar"><span class="author vcard">'.$avatar.'';
					$output .= '<a rel="author" href="'. esc_url( site_url().'/'.$constant.'/'.str_replace(" ","-", $vendor_name) ).'">'. esc_html( $name ).'</a>'; 
					$output .= '</span></span>';
				} else {					
					$output .= '<span class="byline with-avatar"><span class="author vcard">'.$avatar.'';
					$output .= esc_html( $name ); 
					$output .= '</span></span>';
			}
			$output .= '</div>';
			
			if ( class_exists( 'EDD_Reviews' ) ) {		
				$output .= '<div class="right-column reviews align-right reviews-stylethree">';			
				$output .= mp_extension_review_function_vc();			
				$output .= '</div>'; 
			}	
		
		}	
		$output .= "</li>";
		
	}				
		endwhile;
		
		
		
		wp_reset_postdata();
		endif;
		
		$output .= '</ul></div>';
		$output .= "<div class='clear'></div>";			
		$output .= "</div></div>";
		
		
		return $output;	  
	  
    }

    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function loadCssAndJs() {
    
	//wp_register_style( 'slick-slider', plugins_url( 'css/slick.css', __FILE__ ) );
	//wp_enqueue_style( 'slick-slider', plugins_url( 'css/slick.css' , __FILE__ ) );
    
	// If you need any javascript files on front end, here is how you can load them.
	// wp_enqueue_script( 'slick-slider', plugins_url('js/slick.min.js', __FILE__), array('jquery') );	
	 
    }

    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(esc_html__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'kiwi'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new VCExtendAddonClassSlider();